@@ -79,6 +79,15 @@ extern "C" {
 #define strncasecmp strnicmp
 #endif
 
+static void OMC_NO_LAPACK_ERROR() {
+  c_add_message(NULL, -1, ErrorType_runtime, ErrorLevel_error,
+                "A LAPACK routine is called but OMC is not compiled with LAPACK support", NULL, 0);
+  MMC_THROW();
+}
+
+
+#ifdef HAVE_LAPACK
+
 #ifdef HAVE_LAPACK_DEPRECATED
 
 extern int dgeqpf_(integer *m, integer *n, doublereal *a, integer *lda,
@@ -96,8 +105,6 @@ extern int dgelsx_(integer *m, integer *n, integer *nrhs, doublereal *a,
 
 #endif
 
-#ifndef NO_LAPACK
-
 extern int dgeev_(const char *jobvl, const char *jobvr, integer *n,
   doublereal *a, integer *lda, doublereal *wr, doublereal *wi, doublereal *vl,
   integer *ldvl, doublereal *vr, integer *ldvr, doublereal *work,
@@ -315,7 +322,7 @@ void LapackImpl__dgeev(const char *jobvl, const char *jobvr, int N, void *inA, i
     int LDVL, int LDVR, void *inWORK, int LWORK, void **outA, void **WR,
     void **WI, void **VL, void **VR, void **outWORK, int *INFO)
 {
-#ifndef NO_LAPACK
+#ifdef HAVE_LAPACK
   integer n, lda, ldvl, ldvr, lwork, info = 0;
   double *a, *wr, *wi, *vl, *vr, *work;
 
@@ -350,7 +357,7 @@ void LapackImpl__dgeev(const char *jobvl, const char *jobvr, int N, void *inA, i
   free(vl);
   free(vr);
 #else
-  MMC_THROW();
+  OMC_NO_LAPACK_ERROR();
 #endif
 }
 
@@ -399,7 +406,7 @@ void LapackImpl__dgegv(const char *jobvl, const char *jobvr, int N, void *A, int
   free(vr);
   free(work);
 #else
-  MMC_THROW();
+  OMC_NO_LAPACK_ERROR();
 #endif
 }
 
@@ -407,7 +414,7 @@ void LapackImpl__dgels(const char *trans, int M, int N, int NRHS, void *inA,
     int LDA, void *inB, int LDB, void *inWORK, int LWORK, void **outA,
     void **outB, void **outWORK, int *INFO)
 {
-#ifndef NO_LAPACK
+#ifdef HAVE_LAPACK
   integer m, n, nrhs, lda, ldb, lwork, info = 0;
   double *a, *b, *work;
 
@@ -433,7 +440,7 @@ void LapackImpl__dgels(const char *trans, int M, int N, int NRHS, void *inA,
   free(b);
   free(work);
 #else
-  MMC_THROW();
+  OMC_NO_LAPACK_ERROR();
 #endif
 }
 
@@ -471,7 +478,7 @@ void LapackImpl__dgelsx(int M, int N, int NRHS, void *inA, int LDA,
   free(work);
   free(jpvt);
 #else
-  MMC_THROW();
+  OMC_NO_LAPACK_ERROR();
 #endif
 }
 
@@ -479,7 +486,7 @@ void LapackImpl__dgelsy(int M, int N, int NRHS, void *inA, int LDA,
     void *inB, int LDB, void *inJPVT, double rcond, void *inWORK, int LWORK,
     void **outA, void **outB, void **outJPVT, int *RANK, void **outWORK, int *INFO)
 {
-#ifndef NO_LAPACK
+#ifdef HAVE_LAPACK
   integer m, n, nrhs, lda, ldb, rank = 0, info = 0, lwork;
   double *a, *b, *work;
   integer *jpvt;
@@ -510,14 +517,14 @@ void LapackImpl__dgelsy(int M, int N, int NRHS, void *inA, int LDA,
   free(work);
   free(jpvt);
 #else
-  MMC_THROW();
+  OMC_NO_LAPACK_ERROR();
 #endif
 }
 
 void LapackImpl__dgesv(int N, int NRHS, void *inA, int LDA, void *inB,
     int LDB, void **outA, void **IPIV, void **outB, int *INFO)
 {
-#ifndef NO_LAPACK
+#ifdef HAVE_LAPACK
   integer n, nrhs, lda, ldb, info = 0;
   integer *ipiv;
   double *a, *b;
@@ -542,7 +549,7 @@ void LapackImpl__dgesv(int N, int NRHS, void *inA, int LDA, void *inB,
   free(b);
   free(ipiv);
 #else
-  MMC_THROW();
+  OMC_NO_LAPACK_ERROR();
 #endif
 }
 
@@ -551,7 +558,7 @@ void LapackImpl__dgglse(int M, int N, int P, void *inA, int LDA,
     void **outA, void **outB, void **outC, void **outD, void **outX,
     void **outWORK, int *outINFO)
 {
-#ifndef NO_LAPACK
+#ifdef HAVE_LAPACK
   integer m, n, p, lda, ldb, lwork, info = 0;
   double *a, *b, *c, *d, *x, *work;
 
@@ -586,7 +593,7 @@ void LapackImpl__dgglse(int M, int N, int P, void *inA, int LDA,
   free(x);
   free(work);
 #else
-  MMC_THROW();
+  OMC_NO_LAPACK_ERROR();
 #endif
 }
 
@@ -594,7 +601,7 @@ void LapackImpl__dgtsv(int N, int NRHS, void *inDL, void *inD, void *inDU,
     void *inB, int LDB, void **outDL, void **outD, void **outDU, void **outB,
     int *INFO)
 {
-#ifndef NO_LAPACK
+#ifdef HAVE_LAPACK
   integer n, nrhs, ldb, info = 0;
   double *dl, *d, *du, *b;
 
@@ -620,7 +627,7 @@ void LapackImpl__dgtsv(int N, int NRHS, void *inDL, void *inD, void *inDU,
   free(du);
   free(b);
 #else
-  MMC_THROW();
+  OMC_NO_LAPACK_ERROR();
 #endif
 }
 
@@ -628,7 +635,7 @@ void LapackImpl__dgbsv(int N, int KL, int KU, int NRHS, void *inAB,
     int LDAB, void *inB, int LDB, void **outAB, void **IPIV, void **outB,
     int *INFO)
 {
-#ifndef NO_LAPACK
+#ifdef HAVE_LAPACK
   integer n, kl, ku, nrhs, ldab, ldb, info = 0;
   double *ab, *b;
   integer *ipiv;
@@ -655,7 +662,7 @@ void LapackImpl__dgbsv(int N, int KL, int KU, int NRHS, void *inAB,
   free(b);
   free(ipiv);
 #else
-  MMC_THROW();
+  OMC_NO_LAPACK_ERROR();
 #endif
 }
 
@@ -663,7 +670,7 @@ void LapackImpl__dgesvd(const char *jobu, const char *jobvt, int M, int N, void
     int LDA, int LDU, int LDVT, void *inWORK, int LWORK, void **outA,
     void **S, void **U, void **VT, void **outWORK, int *INFO)
 {
-#ifndef NO_LAPACK
+#ifdef HAVE_LAPACK
   integer m, n, lda, ldu, ldvt, lwork, lds, ucol = 0, info = 0;
   double *a, *s, *u = NULL, *vt, *work;
 
@@ -700,14 +707,14 @@ void LapackImpl__dgesvd(const char *jobu, const char *jobvt, int M, int N, void
   free(vt);
   free(work);
 #else
-  MMC_THROW();
+  OMC_NO_LAPACK_ERROR();
 #endif
 }
 
 void LapackImpl__dgetrf(int M, int N, void *inA, int LDA, void **outA,
     void **IPIV, int *INFO)
 {
-#ifndef NO_LAPACK
+#ifdef HAVE_LAPACK
   integer m, n, lda, ldipiv, info = 0;
   double *a;
   integer *ipiv;
@@ -729,14 +736,14 @@ void LapackImpl__dgetrf(int M, int N, void *inA, int LDA, void **outA,
   free(a);
   free(ipiv);
 #else
-  MMC_THROW();
+  OMC_NO_LAPACK_ERROR();
 #endif
 }
 
 void LapackImpl__dgetrs(const char *trans, int N, int NRHS, void *inA, int LDA,
     void *IPIV, void *inB, int LDB, void **outB, int *INFO)
 {
-#ifndef NO_LAPACK
+#ifdef HAVE_LAPACK
   integer n, nrhs, lda, ldb, info = 0;
   double *a, *b;
   integer *ipiv;
@@ -759,14 +766,14 @@ void LapackImpl__dgetrs(const char *trans, int N, int NRHS, void *inA, int LDA,
   free(b);
   free(ipiv);
 #else
-  MMC_THROW();
+  OMC_NO_LAPACK_ERROR();
 #endif
 }
 
 void LapackImpl__dgetri(int N, void *inA, int LDA, void *IPIV, void *inWORK,
     int LWORK, void **outA, void **outWORK, int *INFO)
 {
-#ifndef NO_LAPACK
+#ifdef HAVE_LAPACK
   integer n, lda, lwork, info = 0;
   double *a, *work;
   integer *ipiv;
@@ -789,7 +796,7 @@ void LapackImpl__dgetri(int N, void *inA, int LDA, void *IPIV, void *inWORK,
   free(work);
   free(ipiv);
 #else
-  MMC_THROW();
+  OMC_NO_LAPACK_ERROR();
 #endif
 }
 
@@ -824,7 +831,7 @@ void LapackImpl__dgeqpf(int M, int N, void *inA, int LDA, void *inJPVT,
   free(tau);
   free(work);
 #else
-  MMC_THROW();
+  OMC_NO_LAPACK_ERROR();
 #endif
 }
 
@@ -832,7 +839,7 @@ void LapackImpl__dorgqr(int M, int N, int K, void *inA, int LDA,
     void *TAU, void *inWORK, int LWORK, void **outA, void **outWORK,
     int *INFO)
 {
-#ifndef NO_LAPACK
+#ifdef HAVE_LAPACK
   integer m, n, k, lda, lwork, info = 0;
   double *a, *tau, *work;
 
@@ -856,7 +863,7 @@ void LapackImpl__dorgqr(int M, int N, int K, void *inA, int LDA,
   free(tau);
   free(work);
 #else
-  MMC_THROW();
+  OMC_NO_LAPACK_ERROR();
 #endif
 }
 
