@@ -140,7 +140,7 @@ void setGlobalVerboseLevel(int argc, char**argv)
     return; // no lv flag given.
   }
 
-  /* default activated, but it can be disabled with -stdout or -assert */
+  /* default activated, but it can be disabled with -LOG_STDOUT or -LOG_ASSERT */
   useStream[LOG_STDOUT] = 1;
   useStream[LOG_ASSERT] = 1;
 
@@ -175,11 +175,13 @@ void setGlobalVerboseLevel(int argc, char**argv)
         {
           useStream[i] = 1;
           error = 0;
+          break;
         }
         else if(flag == string("-") + string(LOG_STREAM_NAME[i]))
         {
           useStream[i] = 0;
           error = 0;
+          break;
         }
       }
 
@@ -250,8 +252,12 @@ void setGlobalVerboseLevel(int argc, char**argv)
 }
 
 
-/* Read value of flag lv_time to set time interval in which loggin is active */
-void setGlobalLoggingTime(int argc, char**argv, SIMULATION_INFO *simulationInfo)
+/**
+ * @brief Read value of flag lv_time to set time interval in which logging is active.
+ *
+ * @param simulationInfo    Simulation info struct
+ */
+void setGlobalLoggingTime(SIMULATION_INFO *simulationInfo)
 {
   const char *flagStr = omc_flagValue[FLAG_LV_TIME];
   const string *flags = flagStr ? new string(flagStr) : NULL;
@@ -262,7 +268,7 @@ void setGlobalLoggingTime(int argc, char**argv, SIMULATION_INFO *simulationInfo)
   /* Check if lv_time flag is given */
   if (flagStr==NULL || *flagStr=='\0')
   {
-    /* default activated --> Log everything*/
+    /* default activated --> Log everything */
     simulationInfo->useLoggingTime = 0;
     return;
   }
@@ -274,7 +280,7 @@ void setGlobalLoggingTime(int argc, char**argv, SIMULATION_INFO *simulationInfo)
   loggingStopTime = om_strtod(secondPart, &endptr);
   if (*endptr)
   {
-    throwStreamPrint(NULL, "Simulation flag %s expects two real numbers, seperated by a comata. Got: %s", FLAG_NAME[FLAG_LV_TIME], flagStr);
+    throwStreamPrint(NULL, "Simulation flag %s expects two real numbers, separated by a commas. Got: %s", FLAG_NAME[FLAG_LV_TIME], flagStr);
   }
 
   /* Check flag input */
@@ -287,7 +293,7 @@ void setGlobalLoggingTime(int argc, char**argv, SIMULATION_INFO *simulationInfo)
   simulationInfo->useLoggingTime = 1;
   simulationInfo->loggingTimeRecord[0] = loggingStartTime;
   simulationInfo->loggingTimeRecord[1] = loggingStopTime;
-  infoStreamPrint(LOG_STDOUT, 0, "Time dependent logging enabled. Activate loggin in intervall [%f, %f]", simulationInfo->loggingTimeRecord[0], simulationInfo->loggingTimeRecord[1]);
+  infoStreamPrint(LOG_STDOUT, 0, "Time dependent logging enabled. Activate logging in interval [%f, %f]", simulationInfo->loggingTimeRecord[0], simulationInfo->loggingTimeRecord[1]);
 
   /* Deactivate Logging */
   deactivateLogging();
@@ -823,6 +829,89 @@ static int callSolver(DATA* simData, threadData_t *threadData, string init_initM
   return retVal;
 }
 
+/**
+ * @brief Set log activation from equationIndex and list from lv_system.
+ *
+ * @param data  Data object
+ */
+static void setLVSystems(DATA *data, threadData_t *threadData)
+{
+  int i;
+  int N = 0; /* largest equationIndex */
+  modelica_boolean* a = NULL;
+  const char* p;
+  char* endptr;
+
+  MIXED_SYSTEM_DATA *mixedsys = data->simulationInfo->mixedSystemData;
+  LINEAR_SYSTEM_DATA *linsys = data->simulationInfo->linearSystemData;
+  NONLINEAR_SYSTEM_DATA *nonlinsys = data->simulationInfo->nonlinearSystemData;
+
+  if (omc_flag[FLAG_LV_SYSTEM]) {
+    /* get largest equationIndex */
+    for (i = 0; i < data->modelData->nMixedSystems; ++i)
+      if (mixedsys[i].equationIndex > N)
+        N = mixedsys[i].equationIndex;
+    for (i = 0; i < data->modelData->nLinearSystems; ++i)
+      if (linsys[i].equationIndex > N)
+        N = linsys[i].equationIndex;
+    for (i = 0; i < data->modelData->nNonLinearSystems; ++i)
+      if (nonlinsys[i].equationIndex > N)
+        N = nonlinsys[i].equationIndex;
+
+    /* initialize a with FALSE */
+    a = (modelica_boolean*) calloc(N+1, sizeof(modelica_boolean));
+    assertStreamPrint(threadData, NULL != a, "setLVSystems: Out of memory.");
+
+    /* set a[i] to true for all i in lv_system */
+    p = omc_flagValue[FLAG_LV_SYSTEM];
+    do {
+      errno = 0;
+      i = strtol(p, &endptr, 10);
+      if (errno == ERANGE) {
+        throwStreamPrint(threadData,
+          "setLVSystems: %s takes equation indices (got '%s')",
+          endptr, omc_flagValue[FLAG_LV_SYSTEM]);
+      }
+      if (i > N) {
+        throwStreamPrint(threadData,
+          "setLVSystems: %d is not a valid equation index", i);
+      }
+      a[i] = TRUE;
+      p = endptr;
+    } while(*(p++) == ',');
+
+    /* activate corresponding system */
+    for (i = 0; i < data->modelData->nMixedSystems; ++i) {
+      mixedsys[i].logActive = a[mixedsys[i].equationIndex];
+      a[mixedsys[i].equationIndex] = FALSE;
+    }
+    for (i = 0; i < data->modelData->nLinearSystems; ++i) {
+      linsys[i].logActive = a[linsys[i].equationIndex];
+      a[linsys[i].equationIndex] = FALSE;
+    }
+    for (i = 0; i < data->modelData->nNonLinearSystems; ++i) {
+      nonlinsys[i].logActive = a[nonlinsys[i].equationIndex];
+      a[nonlinsys[i].equationIndex] = FALSE;
+    }
+
+    for (i = 0; i <= N; ++i){
+      if (a[i]) {
+        throwStreamPrint(threadData,
+          "setLVSystems: %d is not a valid equation index.", i);
+      }
+    }
+    /* done */
+    free(a);
+  } else {
+    /* if no list is given then all systems are active */
+    for (i = 0; i < data->modelData->nMixedSystems; ++i)
+      mixedsys[i].logActive = TRUE;
+    for (i = 0; i < data->modelData->nLinearSystems; ++i)
+      linsys[i].logActive = TRUE;
+    for (i = 0; i < data->modelData->nNonLinearSystems; ++i)
+      nonlinsys[i].logActive = TRUE;
+  }
+}
 
 /**
  * Initialization is the same for interactive or non-interactive simulation
@@ -964,7 +1053,14 @@ int initRuntimeAndSimulation(int argc, char**argv, DATA *data, threadData_t *thr
   }
 
   setGlobalVerboseLevel(argc, argv);
-  setGlobalLoggingTime(argc, argv, data->simulationInfo);
+  setGlobalLoggingTime(data->simulationInfo);
+  if(omc_flag[FLAG_LV_MAX_WARN]) {
+    data->simulationInfo->maxWarnDisplays = atoi(omc_flagValue[FLAG_LV_MAX_WARN]);
+    infoStreamPrint(LOG_STDOUT, 0, "Display limit for repeating warnings changed to %lu.", data->simulationInfo->maxWarnDisplays);
+  } else {
+    data->simulationInfo->maxWarnDisplays = DEFAULT_FLAG_LV_MAX_WARN;
+  }
+
   initializeDataStruc(data, threadData);
   if(!data)
   {
@@ -1121,6 +1217,9 @@ int initRuntimeAndSimulation(int argc, char**argv, DATA *data, threadData_t *thr
   initializeLinearSystems(data, threadData);
   initializeNonlinearSystems(data, threadData);
 
+  /* set log activation from equationIndex and lv_system */
+  setLVSystems(data, threadData);
+
   sim_noemit = omc_flag[FLAG_NOEMIT];
 
 #ifndef NO_INTERACTIVE_DEPENDENCY
@@ -1183,17 +1282,6 @@ void communicateMsg(char id, unsigned int size, const char *data)
  * if this is a good idea. However, I am leaving it as it was for now.
  */
 int _main_initRuntimeAndSimulation(int argc, char**argv, DATA *data, threadData_t *threadData) {
-#if defined(__MINGW32__) || defined(_MSC_VER)
-  /* Support for non-ASCII characters
-   * Read the unicode command line arguments and replace the normal arguments with it.
-   */
-  wchar_t** wargv = CommandLineToArgvW(GetCommandLineW(), &argc);
-  for (int i = 0; i < argc; i++) {
-    char* buf = omc_wchar_to_multibyte_str(wargv[i]);
-    strcpy(argv[i], buf);
-    free(buf);
-  }
-#endif
 
   if (initRuntimeAndSimulation(argc, argv, data, threadData)) //initRuntimeAndSimulation returns 1 if an error occurs
     return 1;
@@ -1401,7 +1489,15 @@ void setStreamPrintXML(int isXML)
   }
 }
 
-void communicateStatus(const char *phase, double completionPercent /*0.0 to 1.0*/, double currentTime, double currentStepSize)
+/**
+ * @brief Send status via XMLTCP or TCP.
+ *
+ * @param phase               Simulation phase.
+ * @param completionPercent   Percentage of simulation progress: 0.0 to 1.0
+ * @param currentTime         Current simulation time.
+ * @param currentStepSize     Current solver step size.
+ */
+void communicateStatus(const char *phase, double completionPercent, double currentTime, double currentStepSize)
 {
 #ifndef NO_INTERACTIVE_DEPENDENCY
   if (sim_communication_port_open && isXMLTCP) {
