@@ -1,7 +1,7 @@
 /*
  * This file is part of OpenModelica.
  *
- * Copyright (c) 1998-CurentYear, Open Source Modelica Consortium (OSMC),
+ * Copyright (c) 1998-CurrentYear, Open Source Modelica Consortium (OSMC),
  * c/o Linköpings universitet, Department of Computer and Information Science,
  * SE-58183 Linköping, Sweden.
  *
@@ -54,6 +54,8 @@
 #include "synchronous.h"
 #include "linearSystem.h"
 #include "sym_solver_ssc.h"
+#include "gbode_main.h"
+#include "gbode_util.h"
 #include "irksco.h"
 #if !defined(OMC_MINIMAL_RUNTIME)
 #include "simulation/solver/embedded_server.h"
@@ -93,7 +95,7 @@ static int sym_solver_step(DATA* data, threadData_t *threadData, SOLVER_INFO* so
 
 static int radau_lobatto_step(DATA* data, SOLVER_INFO* solverInfo);
 
-#ifdef WITH_IPOPT
+#ifdef OMC_HAVE_IPOPT
 static int ipopt_step(DATA* data, threadData_t *threadData, SOLVER_INFO* solverInfo);
 #endif
 
@@ -109,14 +111,14 @@ int solver_main_step(DATA* data, threadData_t *threadData, SOLVER_INFO* solverIn
   case S_EULER:
     retVal = euler_ex_step(data, solverInfo);
     if(omc_flag[FLAG_SOLVER_STEPS])
-      data->simulationInfo->solverSteps = solverInfo->solverStats[0] + solverInfo->solverStatsTmp[0];
+      data->simulationInfo->solverSteps = solverInfo->solverStats.nStepsTaken + solverInfo->solverStatsTmp.nStepsTaken;
     TRACE_POP
     return retVal;
   case S_HEUN:
   case S_RUNGEKUTTA:
     retVal = rungekutta_step(data, threadData, solverInfo);
     if(omc_flag[FLAG_SOLVER_STEPS])
-      data->simulationInfo->solverSteps = solverInfo->solverStats[0] + solverInfo->solverStatsTmp[0];
+      data->simulationInfo->solverSteps = solverInfo->solverStats.nStepsTaken + solverInfo->solverStatsTmp.nStepsTaken;
     TRACE_POP
     return retVal;
 
@@ -124,12 +126,12 @@ int solver_main_step(DATA* data, threadData_t *threadData, SOLVER_INFO* solverIn
   case S_DASSL:
     retVal = dassl_step(data, threadData, solverInfo);
     if(omc_flag[FLAG_SOLVER_STEPS])
-      data->simulationInfo->solverSteps = solverInfo->solverStats[0] + solverInfo->solverStatsTmp[0];
+      data->simulationInfo->solverSteps = solverInfo->solverStats.nStepsTaken + solverInfo->solverStatsTmp.nStepsTaken;
     TRACE_POP
     return retVal;
 #endif
 
-#ifdef WITH_IPOPT
+#ifdef OMC_HAVE_IPOPT
   case S_OPTIMIZATION:
     if ((int)(data->modelData->nStates + data->modelData->nInputVars) > 0){
       retVal = ipopt_step(data, threadData, solverInfo);
@@ -138,7 +140,7 @@ int solver_main_step(DATA* data, threadData_t *threadData, SOLVER_INFO* solverIn
       retVal = euler_ex_step(data, solverInfo);
     }
     if(omc_flag[FLAG_SOLVER_STEPS])
-      data->simulationInfo->solverSteps = solverInfo->solverStats[0] + solverInfo->solverStatsTmp[0];
+      data->simulationInfo->solverSteps = solverInfo->solverStats.nStepsTaken + solverInfo->solverStatsTmp.nStepsTaken;
     TRACE_POP
     return retVal;
 #endif
@@ -148,48 +150,51 @@ int solver_main_step(DATA* data, threadData_t *threadData, SOLVER_INFO* solverIn
   case S_IMPRUNGEKUTTA:
     retVal = radau_lobatto_step(data, solverInfo);
     if(omc_flag[FLAG_SOLVER_STEPS])
-      data->simulationInfo->solverSteps = solverInfo->solverStats[0] + solverInfo->solverStatsTmp[0];
+      data->simulationInfo->solverSteps = solverInfo->solverStats.nStepsTaken + solverInfo->solverStatsTmp.nStepsTaken;
     TRACE_POP
     return retVal;
   case S_IDA:
     retVal = ida_solver_step(data, threadData, solverInfo);
     if(omc_flag[FLAG_SOLVER_STEPS])
-      data->simulationInfo->solverSteps = solverInfo->solverStats[0] + solverInfo->solverStatsTmp[0];
+      data->simulationInfo->solverSteps = solverInfo->solverStats.nStepsTaken + solverInfo->solverStatsTmp.nStepsTaken;
     TRACE_POP
     return retVal;
   case S_CVODE:
     retVal = cvode_solver_step(data, threadData, solverInfo);
     if(omc_flag[FLAG_SOLVER_STEPS])
-      data->simulationInfo->solverSteps = solverInfo->solverStats[0] + solverInfo->solverStatsTmp[0];
+      data->simulationInfo->solverSteps = solverInfo->solverStats.nStepsTaken + solverInfo->solverStatsTmp.nStepsTaken;
     TRACE_POP
     return retVal;
 #endif
   case S_ERKSSC:
     retVal = rungekutta_step_ssc(data, threadData, solverInfo);
     if(omc_flag[FLAG_SOLVER_STEPS])
-      data->simulationInfo->solverSteps = solverInfo->solverStats[0] + solverInfo->solverStatsTmp[0];
+      data->simulationInfo->solverSteps = solverInfo->solverStats.nStepsTaken + solverInfo->solverStatsTmp.nStepsTaken;
     TRACE_POP
     return retVal;
   case S_SYM_SOLVER:
     retVal = sym_solver_step(data, threadData, solverInfo);
     if(omc_flag[FLAG_SOLVER_STEPS])
-      data->simulationInfo->solverSteps = solverInfo->solverStats[0] + solverInfo->solverStatsTmp[0];
+      data->simulationInfo->solverSteps = solverInfo->solverStats.nStepsTaken + solverInfo->solverStatsTmp.nStepsTaken;
     return retVal;
   case S_SYM_SOLVER_SSC:
     retVal = sym_solver_ssc_step(data, threadData, solverInfo);
     if(omc_flag[FLAG_SOLVER_STEPS])
-      data->simulationInfo->solverSteps = solverInfo->solverStats[0] + solverInfo->solverStatsTmp[0];
+      data->simulationInfo->solverSteps = solverInfo->solverStats.nStepsTaken + solverInfo->solverStatsTmp.nStepsTaken;
     return retVal;
   case S_IRKSCO:
-  {
     retVal = irksco_midpoint_rule(data, threadData, solverInfo);
     if(omc_flag[FLAG_SOLVER_STEPS])
-      data->simulationInfo->solverSteps = solverInfo->solverStats[0] + solverInfo->solverStatsTmp[0];
+      data->simulationInfo->solverSteps = solverInfo->solverStats.nStepsTaken + solverInfo->solverStatsTmp.nStepsTaken;
     return retVal;
+  case S_GBODE:
+    retVal = gbode_main(data, threadData, solverInfo);
+    if(omc_flag[FLAG_SOLVER_STEPS])
+      data->simulationInfo->solverSteps = solverInfo->solverStats.nStepsTaken + solverInfo->solverStatsTmp.nStepsTaken;
+    return retVal;
+  default:
+    throwStreamPrint(threadData, "Unhandled case in solver_main_step.");
   }
-
-  }
-
   TRACE_POP
   return 1;
 }
@@ -216,12 +221,12 @@ int initializeSolverData(DATA* data, threadData_t *threadData, SOLVER_INFO* solv
   solverInfo->solverRootFinding = 0;
   solverInfo->solverNoEquidistantGrid = 0;
   solverInfo->lastdesiredStep = solverInfo->currentTime + solverInfo->currentStepSize;
-  solverInfo->eventLst = allocList(sizeof(long));
+  solverInfo->eventLst = allocList(eventListAlloc, eventListFree, eventListCopy);
   solverInfo->didEventStep = 0;
   solverInfo->stateEvents = 0;
   solverInfo->sampleEvents = 0;
-  solverInfo->solverStats = (unsigned int*) calloc(numStatistics, sizeof(unsigned int));
-  solverInfo->solverStatsTmp = (unsigned int*) calloc(numStatistics, sizeof(unsigned int));
+  resetSolverStats(&solverInfo->solverStats);
+  resetSolverStats(&solverInfo->solverStatsTmp);
 
   /* if FLAG_NOEQUIDISTANT_GRID is set, choose integrator step method */
   if (omc_flag[FLAG_NOEQUIDISTANT_GRID])
@@ -233,14 +238,14 @@ int initializeSolverData(DATA* data, threadData_t *threadData, SOLVER_INFO* solv
     solverInfo->integratorSteps = 0;
   }
 
-  /* set tolerance for ZeroCrossings */
-  /*  TODO: Check this! */
-  /*  setZCtol(fmin(simInfo->stepSize, simInfo->tolerance)); */
+  /* Deprecation warnings */
+  deprecationWarningGBODE(solverInfo->solverMethod);
 
   switch (solverInfo->solverMethod)
   {
   case S_SYM_SOLVER:
-  case S_EULER: break;
+  case S_EULER:
+  case S_QSS: break;
   case S_SYM_SOLVER_SSC:
   {
     allocateSymSolverSsc(solverInfo, data->modelData->nStates);
@@ -248,7 +253,14 @@ int initializeSolverData(DATA* data, threadData_t *threadData, SOLVER_INFO* solv
   }
   case S_IRKSCO:
   {
-    allocateIrksco(solverInfo, data->modelData->nStates, data->modelData->nZeroCrossings);
+    allocateIrksco(data, threadData, solverInfo, data->modelData->nStates, data->modelData->nZeroCrossings);
+    break;
+  }
+  case S_GBODE:
+  {
+    if (gbode_allocateData(data, threadData, solverInfo) != 0) {
+      throwStreamPrint(threadData, "Failed to allocate memory for generic multigrid solver.");
+    }
     break;
   }
   case S_ERKSSC:
@@ -289,7 +301,6 @@ int initializeSolverData(DATA* data, threadData_t *threadData, SOLVER_INFO* solv
     solverInfo->solverData = rungeData;
     break;
   }
-  case S_QSS: break;
 #if !defined(OMC_MINIMAL_RUNTIME)
   case S_DASSL:
   {
@@ -300,7 +311,7 @@ int initializeSolverData(DATA* data, threadData_t *threadData, SOLVER_INFO* solv
     break;
   }
 #endif
-#ifdef WITH_IPOPT
+#ifdef OMC_HAVE_IPOPT
   case S_OPTIMIZATION:
   {
     infoStreamPrint(LOG_SOLVER, 0, "Initializing optimizer");
@@ -380,62 +391,60 @@ int freeSolverData(DATA* data, SOLVER_INFO* solverInfo)
   int i;
 
   freeList(solverInfo->eventLst);
-  /* free solver statistics */
-  free(solverInfo->solverStats);
-  free(solverInfo->solverStatsTmp);
   /* deintialize solver related workspace */
-  if (solverInfo->solverMethod == S_SYM_SOLVER_SSC)
+  switch (solverInfo->solverMethod)
   {
+  case S_EULER:
+  case S_SYM_SOLVER:
+  case S_QSS: break;
+  case S_SYM_SOLVER_SSC:
     freeSymSolverSsc(solverInfo);
-  }
-  else if(solverInfo->solverMethod == S_RUNGEKUTTA || solverInfo->solverMethod == S_HEUN
-         || solverInfo->solverMethod == S_ERKSSC)
-  {
+    break;
+  case S_RUNGEKUTTA:
+  case S_HEUN:
+  case S_ERKSSC:
     /* free RK work arrays */
     for(i = 0; i < ((RK4_DATA*)(solverInfo->solverData))->work_states_ndims + 1; i++)
       free(((RK4_DATA*)(solverInfo->solverData))->work_states[i]);
     free(((RK4_DATA*)(solverInfo->solverData))->work_states);
     free((RK4_DATA*)solverInfo->solverData);
-  }
-  else if (solverInfo->solverMethod == S_IRKSCO)
-  {
+    break;
+  case S_IRKSCO:
     freeIrksco(solverInfo);
-  }
+    break;
+  case S_GBODE:
+    gbode_freeData(data, solverInfo->solverData);
+    break;
 #if !defined(OMC_MINIMAL_RUNTIME)
-  else if(solverInfo->solverMethod == S_DASSL)
-  {
+  case S_DASSL:
     /* De-Initial DASSL solver */
-    dassl_deinitial(solverInfo->solverData);
-  }
+    dassl_deinitial(data, solverInfo->solverData);
+    break;
 #endif
-#ifdef WITH_IPOPT
-  else if(solverInfo->solverMethod == S_OPTIMIZATION)
-  {
+#ifdef OMC_HAVE_IPOPT
+  case S_OPTIMIZATION:
     /* free  work arrays */
     /*destroyIpopt(solverInfo);*/
-  }
+    break;
 #endif
 #ifdef WITH_SUNDIALS
-  else if(solverInfo->solverMethod == S_IMPEULER ||
-          solverInfo->solverMethod == S_TRAPEZOID ||
-          solverInfo->solverMethod == S_IMPRUNGEKUTTA)
-  {
+  case S_IMPEULER:
+  case S_TRAPEZOID:
+  case S_IMPRUNGEKUTTA:
     /* free  work arrays */
     freeKinOde((KINODE*)solverInfo->solverData);
-  }
-  else if(solverInfo->solverMethod == S_IDA)
-  {
+    break;
+  case S_IDA:
     /* free work arrays */
     ida_solver_deinitial(solverInfo->solverData);
-  }
-  else if(solverInfo->solverMethod == S_CVODE)
-  {
+    break;
+  case S_CVODE:
     /* free work arrays */
     cvode_solver_deinitial(solverInfo->solverData);
-  }
+    break;
 #endif
-  {
-    /* free other solver memory */
+  default:
+    throwStreamPrint(NULL, "Unknown solver %u encountered. Possibly leaking memory!", solverInfo->solverMethod);
   }
 
   return retValue;
@@ -450,7 +459,7 @@ int freeSolverData(DATA* data, SOLVER_INFO* solverInfo)
  *  \param [in]  [pInitFile] extra argument for initialization-method "file"
  *  \param [in]  [initTime] extra argument for initialization-method "file"
  *
- *  This function starts the initialization process of the model .
+ *  This function starts the initialization process of the model.
  */
 int initializeModel(DATA* data, threadData_t *threadData, const char* init_initMethod,
     const char* init_file, double init_time)
@@ -546,7 +555,7 @@ int finishSimulation(DATA* data, threadData_t *threadData, SOLVER_INFO* solverIn
   SIMULATION_INFO *simInfo = data->simulationInfo;
 
   /* Last step with terminal()=true */
-  if(solverInfo->currentTime >= simInfo->stopTime && solverInfo->solverMethod != S_OPTIMIZATION) {
+  if (solverInfo->currentTime >= simInfo->stopTime && solverInfo->solverMethod != S_OPTIMIZATION) {
     infoStreamPrint(LOG_EVENTS_V, 0, "terminal event at stop time %g", solverInfo->currentTime);
     data->simulationInfo->terminal = 1;
     updateDiscreteSystem(data, threadData);
@@ -560,7 +569,11 @@ int finishSimulation(DATA* data, threadData_t *threadData, SOLVER_INFO* solverIn
   }
 
   if (0 != strcmp("ia", data->simulationInfo->outputFormat)) {
-    communicateStatus("Finished", 1, solverInfo->currentTime, solverInfo->currentStepSize);
+    if (simInfo->simulationSuccess) {
+      communicateStatus("Finished", 1, solverInfo->currentTime, solverInfo->currentStepSize);
+    } else {
+      communicateStatus("Simulation aborted", (solverInfo->currentTime-simInfo->startTime)/(simInfo->stopTime-simInfo->startTime), solverInfo->currentTime, 0.0);
+    }
   }
 
   /* we have output variables in the command line -output a,b,c */
@@ -606,15 +619,14 @@ int finishSimulation(DATA* data, threadData_t *threadData, SOLVER_INFO* solverIn
     else
     {
       /* save stats before print */
-      for(ui=0; ui<numStatistics; ui++)
-        solverInfo->solverStats[ui] += solverInfo->solverStatsTmp[ui];
+      addSolverStats(&(solverInfo->solverStats), &(solverInfo->solverStatsTmp));
 
       infoStreamPrint(LOG_STATS, 1, "solver: %s", SOLVER_METHOD_NAME[solverInfo->solverMethod]);
-      infoStreamPrint(LOG_STATS, 0, "%5d steps taken", solverInfo->solverStats[0]);
-      infoStreamPrint(LOG_STATS, 0, "%5d calls of functionODE", solverInfo->solverStats[1]);
-      infoStreamPrint(LOG_STATS, 0, "%5d evaluations of jacobian", solverInfo->solverStats[2]);
-      infoStreamPrint(LOG_STATS, 0, "%5d error test failures", solverInfo->solverStats[3]);
-      infoStreamPrint(LOG_STATS, 0, "%5d convergence test failures", solverInfo->solverStats[4]);
+      infoStreamPrint(LOG_STATS, 0, "%5d steps taken", solverInfo->solverStats.nStepsTaken);
+      infoStreamPrint(LOG_STATS, 0, "%5d calls of functionODE", solverInfo->solverStats.nCallsODE);
+      infoStreamPrint(LOG_STATS, 0, "%5d evaluations of jacobian", solverInfo->solverStats.nCallsJacobian);
+      infoStreamPrint(LOG_STATS, 0, "%5d error test failures", solverInfo->solverStats.nErrorTestFailures);
+      infoStreamPrint(LOG_STATS, 0, "%5d convergence test failures", solverInfo->solverStats.nConvergenveTestFailures);
       infoStreamPrint(LOG_STATS, 0, "%gs time of jacobian evaluation", rt_accumulated(SIM_TIMER_JACOBIAN));
 #ifdef USE_PARJAC
       infoStreamPrint(LOG_STATS, 0, "%i OpenMP-threads used for jacobian evaluation", omc_get_max_threads());
@@ -672,7 +684,7 @@ int finishSimulation(DATA* data, threadData_t *threadData, SOLVER_INFO* solverIn
 
     infoStreamPrint(LOG_STATS_V, 1, "non-linear systems");
     for(ui=0; ui<data->modelData->nNonLinearSystems; ui++)
-      printNonLinearSystemSolvingStatistics(data, ui, LOG_STATS_V);
+      printNonLinearSystemSolvingStatistics(&data->simulationInfo->nonlinearSystemData[ui], LOG_STATS_V);
     messageClose(LOG_STATS_V);
 
     messageClose(LOG_STATS);
@@ -720,13 +732,14 @@ int solver_main(DATA* data, threadData_t *threadData, const char* init_initMetho
     return 1;
 #endif
 
-#ifndef WITH_IPOPT
+#ifndef OMC_HAVE_IPOPT
   case S_OPTIMIZATION:
     warningStreamPrint(LOG_STDOUT, 0, "Ipopt is needed but not available.");
     TRACE_POP
     return 1;
 #endif
-
+  default:
+    break;
   }
 
   /* first initialize the model then allocate SolverData memory
@@ -742,6 +755,13 @@ int solver_main(DATA* data, threadData_t *threadData, const char* init_initMetho
     simInfo->stepSize = simInfo->minStepSize;
     simInfo->numSteps = round((simInfo->stopTime - simInfo->startTime)/simInfo->stepSize);
   }
+  /* Check step size is not larger then stopTime-startTime, up to 6 decimals
+   * Ignored when linearizing model */
+  if (!data->modelData->create_linearmodel && simInfo->stepSize > (simInfo->stopTime - simInfo->startTime + 1e-7)) {
+    warningStreamPrint(LOG_STDOUT, 1, "Integrator step size greater than length of experiment");
+    infoStreamPrint(LOG_STDOUT, 0, "start time: %f, stop time: %f, integrator step size: %f",simInfo->startTime, simInfo->stopTime, simInfo->stepSize);
+    messageClose(LOG_STDOUT);
+  }
 #if !defined(OMC_EMCC)
     MMC_TRY_INTERNAL(simulationJumpBuffer)
 #endif
@@ -891,9 +911,9 @@ static int euler_ex_step(DATA* data, SOLVER_INFO* solverInfo)
 
   /* save stats */
   /* steps */
-  solverInfo->solverStatsTmp[0] += 1;
+  solverInfo->solverStatsTmp.nStepsTaken += 1;
   /* function ODE evaluation is done directly after this function */
-  solverInfo->solverStatsTmp[1] += 1;
+  solverInfo->solverStatsTmp.nCallsODE += 1;
 
   if (measure_time_flag) rt_accumulate(SIM_TIMER_SOLVER);
 
@@ -995,9 +1015,9 @@ static int rungekutta_step_ssc(DATA* data, threadData_t *threadData, SOLVER_INFO
 
     /* save stats */
     /* steps */
-    solverInfo->solverStatsTmp[0] += 1;
+    solverInfo->solverStatsTmp.nStepsTaken += 1;
     /* function ODE evaluation is done directly after this */
-    solverInfo->solverStatsTmp[1] += 4;
+    solverInfo->solverStatsTmp.nCallsODE += 4;
 
 
     //stepsize
@@ -1065,9 +1085,9 @@ static int sym_solver_step(DATA* data, threadData_t *threadData, SOLVER_INFO* so
 
     /* save stats */
     /* steps */
-    solverInfo->solverStatsTmp[0] += 1;
+    solverInfo->solverStatsTmp.nStepsTaken += 1;
     /* function ODE evaluation is done directly after this */
-    solverInfo->solverStatsTmp[1] += 1;
+    solverInfo->solverStatsTmp.nCallsODE += 1;
   }
   else
   /* in case desired step size is too small */
@@ -1137,16 +1157,16 @@ static int rungekutta_step(DATA* data, threadData_t *threadData, SOLVER_INFO* so
 
   /* save stats */
   /* steps */
-  solverInfo->solverStatsTmp[0] += 1;
+  solverInfo->solverStatsTmp.nStepsTaken += 1;
   /* function ODE evaluation is done directly after this */
-  solverInfo->solverStatsTmp[1] += rk->work_states_ndims+1;
+  solverInfo->solverStatsTmp.nCallsODE += rk->work_states_ndims+1;
   if (measure_time_flag) rt_accumulate(SIM_TIMER_SOLVER);
 
   return 0;
 }
 
 /***************************************    Run Ipopt for optimization     ***********************************/
-#if defined(WITH_IPOPT)
+#if defined(OMC_HAVE_IPOPT)
 static int ipopt_step(DATA* data, threadData_t *threadData, SOLVER_INFO* solverInfo)
 {
   int cJ, res;
@@ -1248,3 +1268,33 @@ static void writeOutputVars(char* names, DATA* data)
   }
   fprintf(stdout, "\n"); fflush(stdout);
 }
+
+/**
+ * @brief Set all solver stats to zero.
+ *
+ * @param stats   Pointer to solver stats.
+ */
+void resetSolverStats(SOLVERSTATS* stats) {
+  stats->nStepsTaken = 0;
+  stats->nCallsODE = 0;
+  stats->nCallsJacobian = 0;
+  stats->nErrorTestFailures = 0;
+  stats->nConvergenveTestFailures = 0;
+}
+
+/**
+ * @brief Add two solver statistics.
+ *
+ * destStats += addStats
+ *
+ * @param destStats   Pointer to solver stats to add stats to.
+ *                    On return has result of addition.
+ * @param addStats    Pointer to solver stats to add.
+ */
+void addSolverStats(SOLVERSTATS* destStats, SOLVERSTATS* addStats) {
+  destStats->nStepsTaken              += addStats->nStepsTaken;
+  destStats->nCallsODE                += addStats->nCallsODE;
+  destStats->nCallsJacobian           += addStats->nCallsJacobian;
+  destStats->nErrorTestFailures       += addStats->nErrorTestFailures;
+  destStats->nConvergenveTestFailures += addStats->nConvergenveTestFailures;
+}
