@@ -111,6 +111,7 @@ enum LOG_STREAM
   LOG_JAC,
   LOG_LS,
   LOG_LS_V,
+  LOG_MIXED,
   LOG_NLS,
   LOG_NLS_V,
   LOG_NLS_HOMOTOPY,
@@ -194,6 +195,7 @@ extern void warningStreamPrint(int stream, int indentNext, const char *format, .
 extern void va_warningStreamPrint(int stream, int indentNext, const char *format,va_list ap);
 extern void warningStreamPrintWithEquationIndexes(int stream, FILE_INFO info, int indentNext, const int *indexes, const char *format, ...) __attribute__ ((format (printf, 5, 6)));
 extern void va_warningStreamPrintWithEquationIndexes(int stream, FILE_INFO info, int indentNext, const int *indexes, const char *format,va_list ap);
+extern void warningStreamPrintWithLimit(int stream, int indentNext, unsigned long nDisplayed, unsigned long maxWarnDisplays, const char *format, ...) __attribute__ ((format (printf, 5, 6)));
 extern void errorStreamPrint(int stream, int indentNext, const char *format, ...) __attribute__ ((format (printf, 3, 4)));
 extern void va_errorStreamPrint(int stream, int indentNext, const char *format, va_list ap);
 extern void va_errorStreamPrintWithEquationIndexes(int stream, FILE_INFO info, int indentNext, const int *indexes, const char *format,va_list ap);
@@ -205,6 +207,7 @@ static inline void warningStreamPrint(int stream, int indentNext, const char *fo
 static inline void va_warningStreamPrint(int stream, int indentNext, const char *format,va_list ap) {}
 static inline void warningStreamPrintWithEquationIndexes(int stream, FILE_INFO info, int indentNext, const int *indexes, const char *format, ...) {}
 static inline void va_warningStreamPrintWithEquationIndexes(int stream, FILE_INFO info, int indentNext, const int *indexes, const char *format,va_list ap) {}
+static inline void warningStreamPrintWithLimit(int stream, int indentNext, unsigned long nDisplayed, unsigned long maxWarnDisplays, const char *format, ...) {}
 static inline void errorStreamPrint(int stream, int indentNext, const char *format, ...) {}
 static inline void va_errorStreamPrint(int stream, int indentNext, const char *format, va_list ap) {}
 static inline void va_errorStreamPrintWithEquationIndexes(int stream, FILE_INFO info, int indentNext, const int *indexes, const char *format,va_list ap) {}
@@ -237,8 +240,8 @@ static void OMC_INLINE assertStreamPrint(threadData_t *threadData, int cond, con
 
 #define omc_assert_macro(expr) \
   if (!(expr)) {                \
-    abort(); \
     throwStreamPrint(NULL, "%s:%d: %s: Assertion `%s` failed.\n",  __FILE__, __LINE__, OMC_FUNCTION, #expr); \
+    exit(1); \
   }
 
 #ifdef USE_DEBUG_OUTPUT
