@@ -37,13 +37,7 @@
 
 #include "Util/StringHandler.h"
 #include "Element/Transformation.h"
-#include "FlatModelica/Expression.h"
-#include "BooleanAnnotation.h"
-#include "ColorAnnotation.h"
-#include "ExtentAnnotation.h"
-#include "RealAnnotation.h"
-#include "PointAnnotation.h"
-#include "StringAnnotation.h"
+#include "Modeling/Model.h"
 
 #include <QGraphicsItem>
 #include <QSettings>
@@ -69,6 +63,7 @@ public:
   void setDefaults();
   void setDefaults(ShapeAnnotation *pShapeAnnotation);
   void parseShapeAnnotation(QString annotation);
+  void parseShapeAnnotation(ModelInstance::Shape *pShape);
   QStringList getOMCShapeAnnotation();
   QStringList getShapeAnnotation();
   void setOrigin(QPointF origin) {mOrigin = origin;}
@@ -88,6 +83,7 @@ public:
   void setDefaults();
   void setDefaults(ShapeAnnotation *pShapeAnnotation);
   void parseShapeAnnotation(QString annotation);
+  void parseShapeAnnotation(ModelInstance::Shape *pShape);
   QStringList getOMCShapeAnnotation();
   QStringList getShapeAnnotation();
   QStringList getTextShapeAnnotation();
@@ -98,14 +94,14 @@ public:
   void setLinePattern(StringHandler::LinePattern pattern) {mLinePattern = pattern;}
   StringHandler::LinePattern getLinePattern() {return mLinePattern;}
   void setFillPattern(StringHandler::FillPattern pattern) {mFillPattern = pattern;}
-  StringHandler::FillPattern getFillPattern() {return mFillPattern;}
+  const FillPatternAnnotation &getFillPattern() {return mFillPattern;}
   void setLineThickness(qreal thickness) {mLineThickness = thickness;}
   qreal getLineThickness() {return mLineThickness;}
 protected:
   ColorAnnotation mLineColor;
   ColorAnnotation mFillColor;
-  StringHandler::LinePattern mLinePattern;
-  StringHandler::FillPattern mFillPattern;
+  LinePatternAnnotation mLinePattern;
+  FillPatternAnnotation mFillPattern;
   RealAnnotation mLineThickness;
 };
 
@@ -123,7 +119,7 @@ private:
   QPointF mTransformationStartPosition;
   QPointF mPivotPoint;
   QPointF mOldOrigin;
-  QList<QPointF> mOldExtents;
+  QVector<QPointF> mOldExtents;
   QString mOldAnnotation;
   QAction *mpShapePropertiesAction;
   QAction *mpAlignInterfacesAction;
@@ -132,6 +128,7 @@ private:
 public:
   enum LineGeometryType {VerticalLine, HorizontalLine};
   Transformation mTransformation;
+  ShapeAnnotation(QGraphicsItem *pParent);
   ShapeAnnotation(ShapeAnnotation *pShapeAnnotation, QGraphicsItem *pParent);
   ShapeAnnotation(bool inheritedShape, GraphicsView *pGraphicsView, ShapeAnnotation *pShapeAnnotation, QGraphicsItem *pParent = 0);
   void setDefaults();
@@ -147,7 +144,8 @@ public:
   virtual QString getOMCShapeAnnotation() = 0;
   virtual QString getOMCShapeAnnotationWithShapeName() = 0;
   virtual QString getShapeAnnotation() = 0;
-  static QList<QPointF> getExtentsForInheritedShapeFromIconDiagramMap(GraphicsView *pGraphicsView, ShapeAnnotation *pReferenceShapeAnnotation);
+  virtual void drawAnnotation(QPainter *painter) = 0;
+  QList<QPointF> getExtentsForInheritedShapeFromIconDiagramMap(GraphicsView *pGraphicsView, ShapeAnnotation *pReferenceShapeAnnotation);
   void applyTransformation();
   void drawCornerItems();
   void setCornerItemsActiveOrPassive();
@@ -167,8 +165,9 @@ public:
   void setOriginItemPos(const QPointF point);
   GraphicsView* getGraphicsView() {return mpGraphicsView;}
   OriginItem* getOriginItem() {return mpOriginItem;}
-  void setPoints(QList<QPointF> points) {mPoints = points;}
-  QList<QPointF> getPoints() {return mPoints;}
+  void setPoints(QVector<QPointF> points) {mPoints = points;}
+  const PointArrayAnnotation &getPoints() {return mPoints;}
+  const ArrowAnnotation &getArrow() {return mArrow;}
   void setStartArrow(StringHandler::Arrow startArrow) {mArrow.replace(0, startArrow);}
   StringHandler::Arrow getStartArrow() {return mArrow.at(0);}
   void setEndArrow(StringHandler::Arrow endArrow) {mArrow.replace(1, endArrow);}
@@ -177,8 +176,8 @@ public:
   qreal getArrowSize() {return mArrowSize;}
   void setSmooth(StringHandler::Smooth smooth) {mSmooth = smooth;}
   StringHandler::Smooth getSmooth() {return mSmooth;}
-  void setExtents(QList<QPointF> extents) {mExtents = extents;}
-  QList<QPointF> getExtents() {return mExtents;}
+  void setExtents(QVector<QPointF> extents) {mExtent = extents;}
+  const QVector<QPointF> &getExtents() {return mExtent;}
   void setBorderPattern(StringHandler::BorderPattern pattern) {mBorderPattern = pattern;}
   StringHandler::BorderPattern getBorderPattern() {return mBorderPattern;}
   void setRadius(qreal radius) {mRadius = radius;}
@@ -190,13 +189,13 @@ public:
   void setClosure(StringHandler::EllipseClosure closure) {mClosure = closure;}
   StringHandler::EllipseClosure getClosure() {return mClosure;}
   void setTextString(QString textString);
-  QString getTextString() {return mTextString;}
+  const QString &getTextString() {return mTextString;}
   void setFontName(QString fontName) {mFontName = fontName;}
-  QString getFontName() {return mFontName;}
+  const QString &getFontName() {return mFontName;}
   void setFontSize(qreal fontSize) {mFontSize = fontSize;}
   qreal getFontSize() {return mFontSize;}
-  void setTextStyles(QList<StringHandler::TextStyle> textStyles) {mTextStyles = textStyles;}
-  QList<StringHandler::TextStyle> getTextStyles() {return mTextStyles;}
+  void setTextStyles(QVector<StringHandler::TextStyle> textStyles) {mTextStyles = textStyles;}
+  const QVector<StringHandler::TextStyle> &getTextStyles() {return mTextStyles;}
   void setTextHorizontalAlignment(StringHandler::TextAlignment textAlignment) {mHorizontalAlignment = textAlignment;}
   StringHandler::TextAlignment getTextHorizontalAlignment() {return mHorizontalAlignment;}
   void setFileName(QString fileName);
@@ -217,11 +216,11 @@ public:
   void moveShape(const qreal dx, const qreal dy);
   virtual void setShapeFlags(bool enable);
   virtual void updateShape(ShapeAnnotation *pShapeAnnotation) = 0;
+  virtual ModelInstance::Extend* getExtend() const = 0;
   void emitAdded() {emit added();}
   void emitChanged() {emit changed();}
   void emitDeleted() {emit deleted();}
   void emitPrepareGeometryChange() {prepareGeometryChange();}
-  static int maxTextLengthToShowOnLibraryIcon;
 signals:
   void added();
   void changed();
@@ -266,22 +265,23 @@ protected:
   GraphicsView *mpGraphicsView;
   Element *mpParentComponent;
   OriginItem *mpOriginItem;
-  QList<QPointF> mPoints;
+  PointArrayAnnotation mPoints;
   QList<LineGeometryType> mGeometries;
-  QList<StringHandler::Arrow> mArrow;
+  ArrowAnnotation mArrow;
   RealAnnotation mArrowSize;
-  StringHandler::Smooth mSmooth;
-  ExtentAnnotation mExtents;
-  StringHandler::BorderPattern mBorderPattern;
+  SmoothAnnotation mSmooth;
+  ExtentAnnotation mExtent;
+  BorderPatternAnnotation mBorderPattern;
   RealAnnotation mRadius;
   RealAnnotation mStartAngle;
   RealAnnotation mEndAngle;
-  StringHandler::EllipseClosure mClosure;
+  EllipseClosureAnnotation mClosure;
+  StringAnnotation mOriginalTextString;
   StringAnnotation mTextString;
   RealAnnotation mFontSize;
-  QString mFontName;
-  QList<StringHandler::TextStyle> mTextStyles;
-  StringHandler::TextAlignment mHorizontalAlignment;
+  StringAnnotation mFontName;
+  TextStyleAnnotation mTextStyles;
+  TextAlignmentAnnotation mHorizontalAlignment;
   QString mOriginalFileName;
   QString mFileName;
   QString mClassFileName; /* Used to find the bitmap relative locations. */
