@@ -125,8 +125,8 @@ TextAnnotation::TextAnnotation(Element *pParent)
   FilledShape::setDefaults();
   ShapeAnnotation::setDefaults();
   // give a reasonable size to default element text
-  mExtents.replace(0, QPointF(-100, -50));
-  mExtents.replace(1, QPointF(100, 50));
+  mExtent.replace(0, QPointF(-100, -50));
+  mExtent.replace(1, QPointF(100, 50));
   setTextString("%name");
   initUpdateTextString();
   setPos(mOrigin);
@@ -150,9 +150,9 @@ TextAnnotation::TextAnnotation(QString annotation, LineAnnotation *pLineAnnotati
    */
   if (pLineAnnotation->getPoints().size() > 0) {
     if (pLineAnnotation->getImmediate()) {
-      setPos(pLineAnnotation->getPoints().last());
+      setPos(pLineAnnotation->getPoints().at(mPoints.size() - 1));
     } else {
-      setPos(pLineAnnotation->getPoints().first());
+      setPos(pLineAnnotation->getPoints().at(0));
     }
   }
 }
@@ -175,9 +175,9 @@ TextAnnotation::TextAnnotation(ModelInstance::Text *pText, LineAnnotation *pLine
    */
   if (pLineAnnotation->getPoints().size() > 0) {
     if (pLineAnnotation->getImmediate()) {
-      setPos(pLineAnnotation->getPoints().last());
+      setPos(pLineAnnotation->getPoints().at(mPoints.size() - 1));
     } else {
-      setPos(pLineAnnotation->getPoints().first());
+      setPos(pLineAnnotation->getPoints().at(0));
     }
   }
 }
@@ -198,8 +198,8 @@ TextAnnotation::TextAnnotation(GraphicsView *pGraphicsView)
   FilledShape::setDefaults();
   ShapeAnnotation::setDefaults();
   // give a reasonable size
-  mExtents.replace(0, QPointF(-100, 20));
-  mExtents.replace(1, QPointF(100, -20));
+  mExtent.replace(0, QPointF(-100, 20));
+  mExtent.replace(1, QPointF(100, -20));
   setTextString("%name");
   initUpdateTextString();
   setPos(mOrigin);
@@ -222,7 +222,7 @@ void TextAnnotation::parseShapeAnnotation(QString annotation)
     return;
   }
   // 9th item of the list contains the extent points
-  mExtents.parse(list.at(8));
+  mExtent.parse(list.at(8));
   // 10th item of the list contains the textString.
   mTextString.parse(list.at(9));
   mOriginalTextString = mTextString;
@@ -235,9 +235,9 @@ void TextAnnotation::parseShapeAnnotation(QString annotation)
     mLineColor.parse(list.at(11));
   }
   // 13th item of the list contains the font name.
-  QString fontName = StringHandler::removeFirstLastQuotes(stripDynamicSelect(list.at(12)));
-  if (!fontName.isEmpty()) {
-    mFontName = fontName;
+  const QString fontName = list.at(12);
+  if (!StringHandler::removeFirstLastQuotes(fontName).isEmpty()) {
+    mFontName.parse(fontName);
   }
   // 14th item of the list contains the text styles.
   QStringList textStyles = StringHandler::getStrings(StringHandler::removeFirstLastCurlBrackets(stripDynamicSelect(list.at(13))));
@@ -266,42 +266,26 @@ void TextAnnotation::parseShapeAnnotation()
   GraphicItem::parseShapeAnnotation(mpText);
   FilledShape::parseShapeAnnotation(mpText);
 
-  QList<QPointF> extents;
-  ModelInstance::Extent extent = mpText->getExtent();
-  ModelInstance::Point extent1 = extent.getExtent1();
-  ModelInstance::Point extent2 = extent.getExtent2();
-  extents.append(QPointF(extent1.x(), extent1.y()));
-  extents.append(QPointF(extent2.x(), extent2.y()));
-  mExtents = extents;
+  mExtent = mpText->getExtent();
+  mExtent.evaluate(mpText->getParentModel());
   mTextString = mpText->getTextString();
   mOriginalTextString = mTextString;
   initUpdateTextString();
 
   mFontSize = mpText->getFontSize();
-  if (mpText->getTextColor().getColor().isValid()) {
-    mLineColor = mpText->getTextColor().getColor();
+  mFontSize.evaluate(mpText->getParentModel());
+  if (mpText->getTextColor().isValid()) {
+    mLineColor = mpText->getTextColor();
+    mLineColor.evaluate(mpText->getParentModel());
   }
   if (!mpText->getFontName().isEmpty()) {
-    mFontName = mpText->getFontName().isEmpty();
-  }
-  QStringList textStyles = mpText->getTextStyle();
-  foreach (QString textStyle, textStyles) {
-    if (textStyle == "TextStyle.Bold") {
-      mTextStyles.append(StringHandler::TextStyleBold);
-    } else if (textStyle == "TextStyle.Italic") {
-      mTextStyles.append(StringHandler::TextStyleItalic);
-    } else if (textStyle == "TextStyle.UnderLine") {
-      mTextStyles.append(StringHandler::TextStyleUnderLine);
-    }
-  }
-  QString horizontalAlignment = StringHandler::removeFirstLastQuotes(stripDynamicSelect(mpText->getHorizontalAlignment()));
-  if (horizontalAlignment == "TextAlignment.Left") {
-    mHorizontalAlignment = StringHandler::TextAlignmentLeft;
-  } else if (horizontalAlignment == "TextAlignment.Center") {
-    mHorizontalAlignment = StringHandler::TextAlignmentCenter;
-  } else if (horizontalAlignment == "TextAlignment.Right") {
-    mHorizontalAlignment = StringHandler::TextAlignmentRight;
+    mFontName = mpText->getFontName();
+    mFontName.evaluate(mpText->getParentModel());
   }
+  mTextStyles = mpText->getTextStyle();
+  mTextStyles.evaluate(mpText->getParentModel());
+  mHorizontalAlignment = mpText->getHorizontalAlignment();
+  mHorizontalAlignment.evaluate(mpText->getParentModel());
 }
 
 /*!
@@ -349,7 +333,7 @@ void TextAnnotation::paint(QPainter *painter, const QStyleOptionGraphicsItem *op
     // state machine visualization
     // text annotation on a element
     if (mpElement && mpElement->getGraphicsView()->isVisualizationView()
-        && ((mpElement->getGraphicsView()->getModelWidget()->isNewApi() && mpElement->getModel() && mpElement->getModel()->isState())
+        && ((mpElement->getGraphicsView()->getModelWidget()->isNewApi() && mpElement->getModel() && mpElement->getModel()->getAnnotation()->isState())
             || (mpElement->getLibraryTreeItem() && mpElement->getLibraryTreeItem()->isState()))) {
       if (mpElement->isActiveState()) {
         painter->setOpacity(1.0);
@@ -359,7 +343,7 @@ void TextAnnotation::paint(QPainter *painter, const QStyleOptionGraphicsItem *op
     }
     // text annotation on a transition
     LineAnnotation *pTransitionLineAnnotation = dynamic_cast<LineAnnotation*>(parentItem());
-    if (pTransitionLineAnnotation && pTransitionLineAnnotation->getLineType() == LineAnnotation::TransitionType
+    if (pTransitionLineAnnotation && pTransitionLineAnnotation->isTransition()
         && pTransitionLineAnnotation->getGraphicsView() && pTransitionLineAnnotation->getGraphicsView()->isVisualizationView()) {
       if (pTransitionLineAnnotation->isActiveState()) {
         painter->setOpacity(1.0);
@@ -367,16 +351,16 @@ void TextAnnotation::paint(QPainter *painter, const QStyleOptionGraphicsItem *op
         painter->setOpacity(0.2);
       }
     }
-    drawTextAnnotation(painter);
+    drawAnnotation(painter);
   }
 }
 
 /*!
- * \brief TextAnnotation::drawTextAnnotation
- * Draws the Text annotation
+ * \brief TextAnnotation::drawAnnotation
+ * Draws the text.
  * \param painter
  */
-void TextAnnotation::drawTextAnnotation(QPainter *painter)
+void TextAnnotation::drawAnnotation(QPainter *painter)
 {
   applyLinePattern(painter);
   /* Don't apply the fill patterns on Text shapes. */
@@ -412,9 +396,10 @@ void TextAnnotation::drawTextAnnotation(QPainter *painter)
     sy = scaleY;
   }
   // map the existing bounding rect to new transformation
-  QRectF mappedBoundingRect = QRectF(boundingRect().x() * sx, boundingRect().y() * sy, boundingRect().width() * sx, boundingRect().height() * sy);
+  QRectF boundingRectangle = boundingRect();
+  QRectF mappedBoundingRect = QRectF(boundingRectangle.x() * sx, boundingRectangle.y() * sy, boundingRectangle.width() * sx, boundingRectangle.height() * sy);
   // map the existing bounding rect to new transformation but with positive width and height so that font metrics can work
-  QRectF absMappedBoundingRect = QRectF(boundingRect().x() * sx, boundingRect().y() * sy, qAbs(boundingRect().width() * sx), qAbs(boundingRect().height() * sy));
+  QRectF absMappedBoundingRect = QRectF(boundingRectangle.x() * sx, boundingRectangle.y() * sy, qAbs(boundingRectangle.width() * sx), qAbs(boundingRectangle.height() * sy));
   // normalize the text for drawing
   QString textString = StringHandler::removeFirstLastQuotes(mTextString);
   textString = StringHandler::unparse(QString("\"").append(mTextString).append("\""));
@@ -424,12 +409,10 @@ void TextAnnotation::drawTextAnnotation(QPainter *painter)
   if (mFontSize > 0) {
     font.setPointSizeF(mFontSize);
   }
-  font.setWeight(StringHandler::getFontWeight(mTextStyles));
-  font.setItalic(StringHandler::getFontItalic(mTextStyles));
+  font.setWeight(mTextStyles.getWeight());
+  font.setItalic(mTextStyles.isItalic());
   // set font underline
-  if (StringHandler::getFontUnderline(mTextStyles)) {
-    font.setUnderline(true);
-  }
+  font.setUnderline(mTextStyles.isUnderLine());
   painter->setFont(font);
   /* From Modelica specification version 3.5-dev
    * "The style attribute fontSize specifies the font size. If the fontSize attribute is 0 the text is scaled to fit its extent. Otherwise, the size specifies the absolute size."
@@ -478,31 +461,19 @@ QString TextAnnotation::getOMCShapeAnnotation()
   annotationString.append(GraphicItem::getOMCShapeAnnotation());
   annotationString.append(FilledShape::getOMCShapeAnnotation());
   // get the extents
-  annotationString.append(mExtents.toQString());
+  annotationString.append(mExtent.toQString());
   // get the text string
   annotationString.append(mOriginalTextString.toQString());
   // get the font size
   annotationString.append(mFontSize.toQString());
   // get the text color
   annotationString.append(mLineColor.toQString());
-  // get the font name
-  if (!mFontName.isEmpty() && mFontName.compare(Helper::systemFontInfo.family()) != 0) {
-    annotationString.append(QString("\"").append(mFontName).append("\""));
-  } else {
-    annotationString.append(QString("\"\""));
-  }
-  // get the font styles
-  QString textStylesString;
-  QStringList stylesList;
-  textStylesString.append("{");
-  for (int i = 0 ; i < mTextStyles.size() ; i++) {
-    stylesList.append(StringHandler::getTextStyleString(mTextStyles[i]));
-  }
-  textStylesString.append(stylesList.join(","));
-  textStylesString.append("}");
-  annotationString.append(textStylesString);
-  // get the font horizontal alignment
-  annotationString.append(StringHandler::getTextAlignmentString(mHorizontalAlignment));
+  // font name
+  annotationString.append(mFontName.toQString());
+  // text style
+  annotationString.append(mTextStyles.toQString());
+  // horizontal alignment
+  annotationString.append(mHorizontalAlignment.toQString());
   return annotationString.join(",");
 }
 
@@ -525,39 +496,29 @@ QString TextAnnotation::getShapeAnnotation()
   annotationString.append(GraphicItem::getShapeAnnotation());
   annotationString.append(FilledShape::getTextShapeAnnotation());
   // get the extents
-  if (mExtents.isDynamicSelectExpression() || mExtents.size() > 1) {
-    annotationString.append(QString("extent=%1").arg(mExtents.toQString()));
+  if (mExtent.isDynamicSelectExpression() || mExtent.size() > 1) {
+    annotationString.append(QString("extent=%1").arg(mExtent.toQString()));
   }
   // get the text string
   annotationString.append(QString("textString=%1").arg(mOriginalTextString.toQString()));
   // get the font size
-  if (mFontSize.isDynamicSelectExpression() || mFontSize != 0) {
+  if (mFontSize.isDynamicSelectExpression() || mFontSize.toQString().compare(QStringLiteral("0")) != 0) {
     annotationString.append(QString("fontSize=%1").arg(mFontSize.toQString()));
   }
   // get the font name
   /* Ticket:4204
    * Don't insert the default font name as it might be operating system specific.
    */
-  if (!mFontName.isEmpty() && mFontName.compare(Helper::systemFontInfo.family()) != 0) {
-    annotationString.append(QString("fontName=\"").append(mFontName).append("\""));
+  if (mFontName.isDynamicSelectExpression() || (!mFontName.isEmpty() && StringHandler::removeFirstLastQuotes(mFontName.toQString()).compare(Helper::systemFontInfo.family()) != 0)) {
+    annotationString.append(QString("fontName=%1").arg(mFontName.toQString()));
   }
   // get the font styles
-  QString textStylesString;
-  QStringList stylesList;
   if (mTextStyles.size() > 0) {
-    textStylesString.append("textStyle={");
-  }
-  for (int i = 0 ; i < mTextStyles.size() ; i++) {
-    stylesList.append(StringHandler::getTextStyleString(mTextStyles[i]));
-  }
-  if (mTextStyles.size() > 0) {
-    textStylesString.append(stylesList.join(","));
-    textStylesString.append("}");
-    annotationString.append(textStylesString);
+    annotationString.append(QString("textStyle=%1").arg(mTextStyles.toQString()));
   }
   // get the font horizontal alignment
-  if (mHorizontalAlignment != StringHandler::TextAlignmentCenter) {
-    annotationString.append(QString("horizontalAlignment=").append(StringHandler::getTextAlignmentString(mHorizontalAlignment)));
+  if (mHorizontalAlignment.isDynamicSelectExpression() || mHorizontalAlignment.toQString().compare(QStringLiteral("TextAlignment.Center")) != 0) {
+    annotationString.append(QString("horizontalAlignment=%1").arg(mHorizontalAlignment.toQString()));
   }
   return QString("Text(").append(annotationString.join(",")).append(")");
 }
@@ -570,6 +531,11 @@ void TextAnnotation::updateShape(ShapeAnnotation *pShapeAnnotation)
   ShapeAnnotation::setDefaults(pShapeAnnotation);
 }
 
+ModelInstance::Extend *TextAnnotation::getExtend() const
+{
+  return mpText->getParentExtend();
+}
+
 void TextAnnotation::initUpdateTextString()
 {
   if (mpElement) {
@@ -603,13 +569,13 @@ void TextAnnotation::updateTextStringHelper(QRegExp regExp)
           QString unit = mpElement->getRootParentElement()->getParameterModifierValue(variable, "unit");
           QString displayUnit = mpElement->getRootParentElement()->getParameterModifierValue(variable, "displayUnit");
           if (MainWindow::instance()->isNewApi()) {
-            ModelInstance::Element* pModelElement = Element::getModelElementByName(mpElement->getRootParentElement()->getModel(), variable);
-            if (pModelElement) {
+            ModelInstance::Component* pModelComponent = Element::getModelComponentByName(mpElement->getRootParentElement()->getModel(), variable);
+            if (pModelComponent) {
               if (displayUnit.isEmpty()) {
-                displayUnit = pModelElement->getModifierValueFromType(QStringList() << "displayUnit");
+                displayUnit = pModelComponent->getModifierValueFromType(QStringList() << "displayUnit");
               }
               if (unit.isEmpty()) {
-                unit = pModelElement->getModifierValueFromType(QStringList() << "unit");
+                unit = pModelComponent->getModifierValueFromType(QStringList() << "unit");
               }
             }
           } else {
