@@ -262,8 +262,7 @@ void AddComponentCommand::redoInternal()
   if (mpLibraryTreeItem && mpLibraryTreeItem->isConnector() && pModelWidget->getLibraryTreeItem()->getLibraryType() == LibraryTreeItem::Modelica) {
     // Connector type components exists on icon view as well
     if (mpIconComponent->mTransformation.isValid() && mpIconComponent->mTransformation.getVisible()) {
-      mpIconGraphicsView->addItem(mpIconComponent);
-      mpIconGraphicsView->addItem(mpIconComponent->getOriginItem());
+      mpIconGraphicsView->addElementItem(mpIconComponent);
     }
     mpIconGraphicsView->addElementToList(mpIconComponent);
     mpIconGraphicsView->deleteElementFromOutOfSceneList(mpIconComponent);
@@ -272,8 +271,7 @@ void AddComponentCommand::redoInternal()
     mpIconComponent->setVisible(!mpComponentInfo->getProtected());
   }
   if (mpDiagramComponent->mTransformation.isValid() && mpDiagramComponent->mTransformation.getVisible()) {
-    mpDiagramGraphicsView->addItem(mpDiagramComponent);
-    mpDiagramGraphicsView->addItem(mpDiagramComponent->getOriginItem());
+    mpDiagramGraphicsView->addElementItem(mpDiagramComponent);
   }
   mpDiagramGraphicsView->addElementToList(mpDiagramComponent);
   mpDiagramGraphicsView->deleteElementFromOutOfSceneList(mpDiagramComponent);
@@ -304,29 +302,27 @@ void AddComponentCommand::undo()
   // if component is of connector type && containing class is Modelica type.
   if (mpLibraryTreeItem && mpLibraryTreeItem->isConnector() && pModelWidget->getLibraryTreeItem()->getLibraryType() == LibraryTreeItem::Modelica) {
     // Connector type components exists on icon view as well
-    mpIconGraphicsView->removeItem(mpIconComponent);
-    mpIconGraphicsView->removeItem(mpIconComponent->getOriginItem());
+    mpIconGraphicsView->removeElementItem(mpIconComponent);
     mpIconGraphicsView->deleteElementFromList(mpIconComponent);
     mpIconGraphicsView->addElementToOutOfSceneList(mpIconComponent);
     mpIconComponent->emitDeleted();
   }
-  mpDiagramGraphicsView->removeItem(mpDiagramComponent);
-  mpDiagramGraphicsView->removeItem(mpDiagramComponent->getOriginItem());
+  mpDiagramGraphicsView->removeElementItem(mpDiagramComponent);
   mpDiagramGraphicsView->deleteElementFromList(mpDiagramComponent);
   mpDiagramGraphicsView->addElementToOutOfSceneList(mpDiagramComponent);
   mpDiagramComponent->emitDeleted();
   mpDiagramGraphicsView->deleteElementFromClass(mpDiagramComponent);
 }
 
-UpdateComponentTransformationsCommand::UpdateComponentTransformationsCommand(Element *pComponent, const Transformation &oldTransformation, const Transformation &newTransformation,
+UpdateComponentTransformationsCommand::UpdateComponentTransformationsCommand(Element *pComponent, Transformation oldTransformation, Transformation newTransformation,
                                                                              const bool positionChanged, const bool moveConnectorsTogether, UndoCommand *pParent)
-  : UndoCommand(pParent)
+  : UndoCommand(pParent),
+    mpComponent(pComponent),
+    mOldTransformation(std::move(oldTransformation)),
+    mNewTransformation(std::move(newTransformation)),
+    mPositionChanged(positionChanged),
+    mMoveConnectorsTogether(moveConnectorsTogether)
 {
-  mpComponent = pComponent;
-  mOldTransformation = oldTransformation;
-  mNewTransformation = newTransformation;
-  mPositionChanged = positionChanged;
-  mMoveConnectorsTogether = moveConnectorsTogether;
   setText(QString("Update Component %1 Transformations").arg(mpComponent->getName()));
 }
 
@@ -337,8 +333,9 @@ UpdateComponentTransformationsCommand::UpdateComponentTransformationsCommand(Ele
 void UpdateComponentTransformationsCommand::redoInternal()
 {
   ModelWidget *pModelWidget = mpComponent->getGraphicsView()->getModelWidget();
-  if (mpComponent->getLibraryTreeItem() && mpComponent->getLibraryTreeItem()->isConnector() && mMoveConnectorsTogether &&
-      pModelWidget->getLibraryTreeItem()->getLibraryType() == LibraryTreeItem::Modelica) {
+  if (mMoveConnectorsTogether && pModelWidget->getLibraryTreeItem()->getLibraryType() == LibraryTreeItem::Modelica
+      && ((mpComponent->getLibraryTreeItem() && mpComponent->getLibraryTreeItem()->isConnector())
+          || (pModelWidget->isNewApi() && mpComponent->getModel() && mpComponent->getModel()->isConnector()))) {
     GraphicsView *pGraphicsView;
     if (mpComponent->getGraphicsView()->getViewType() == StringHandler::Icon) {
       pGraphicsView = pModelWidget->getDiagramGraphicsView();
@@ -366,6 +363,9 @@ void UpdateComponentTransformationsCommand::redoInternal()
   mpComponent->mTransformation = mNewTransformation;
   mpComponent->emitTransformChange(mPositionChanged);
   mpComponent->emitTransformHasChanged();
+  if (mpComponent->getGraphicsView()->getViewType() == StringHandler::Diagram && mpComponent->getGraphicsView()->getModelWidget()->isNewApi()) {
+    mpComponent->getGraphicsView()->handleCollidingConnections();
+  }
 }
 
 /*!
@@ -375,8 +375,9 @@ void UpdateComponentTransformationsCommand::redoInternal()
 void UpdateComponentTransformationsCommand::undo()
 {
   ModelWidget *pModelWidget = mpComponent->getGraphicsView()->getModelWidget();
-  if (mpComponent->getLibraryTreeItem() && mpComponent->getLibraryTreeItem()->isConnector() && mMoveConnectorsTogether &&
-      pModelWidget->getLibraryTreeItem()->getLibraryType() == LibraryTreeItem::Modelica) {
+  if (mMoveConnectorsTogether && pModelWidget->getLibraryTreeItem()->getLibraryType() == LibraryTreeItem::Modelica
+      && ((mpComponent->getLibraryTreeItem() && mpComponent->getLibraryTreeItem()->isConnector())
+          || (pModelWidget->isNewApi() && mpComponent->getModel() && mpComponent->getModel()->isConnector()))) {
     GraphicsView *pGraphicsView;
     if (mpComponent->getGraphicsView()->getViewType() == StringHandler::Icon) {
       pGraphicsView = pModelWidget->getDiagramGraphicsView();
@@ -404,6 +405,9 @@ void UpdateComponentTransformationsCommand::undo()
   mpComponent->mTransformation = mOldTransformation;
   mpComponent->emitTransformChange(mPositionChanged);
   mpComponent->emitTransformHasChanged();
+  if (mpComponent->getGraphicsView()->getViewType() == StringHandler::Diagram && mpComponent->getGraphicsView()->getModelWidget()->isNewApi()) {
+    mpComponent->getGraphicsView()->handleCollidingConnections();
+  }
 }
 
 UpdateElementAttributesCommand::UpdateElementAttributesCommand(Element *pComponent, const ElementInfo &oldComponentInfo, const ElementInfo &newComponentInfo, UndoCommand *pParent)
@@ -697,15 +701,13 @@ void DeleteComponentCommand::redoInternal()
     }
     Element *pComponent = pGraphicsView->getElementObject(mpComponent->getName());
     if (pComponent) {
-      pGraphicsView->removeItem(pComponent);
-      pGraphicsView->removeItem(pComponent->getOriginItem());
+      pGraphicsView->removeElementItem(pComponent);
       pGraphicsView->deleteElementFromList(pComponent);
       pGraphicsView->addElementToOutOfSceneList(pComponent);
       pComponent->emitDeleted();
     }
   }
-  mpGraphicsView->removeItem(mpComponent);
-  mpGraphicsView->removeItem(mpComponent->getOriginItem());
+  mpGraphicsView->removeElementItem(mpComponent);
   mpGraphicsView->deleteElementFromList(mpComponent);
   mpGraphicsView->addElementToOutOfSceneList(mpComponent);
   mpComponent->emitDeleted();
@@ -730,15 +732,13 @@ void DeleteComponentCommand::undo()
     }
     Element *pComponent = pGraphicsView->getElementObject(mpComponent->getName());
     if (pComponent) {
-      pGraphicsView->addItem(pComponent);
-      pGraphicsView->addItem(pComponent->getOriginItem());
+      pGraphicsView->addElementItem(pComponent);
       pGraphicsView->addElementToList(pComponent);
       pGraphicsView->deleteElementFromOutOfSceneList(pComponent);
       pComponent->emitAdded();
     }
   }
-  mpGraphicsView->addItem(mpComponent);
-  mpGraphicsView->addItem(mpComponent->getOriginItem());
+  mpGraphicsView->addElementItem(mpComponent);
   mpGraphicsView->addElementToList(mpComponent);
   mpGraphicsView->deleteElementFromOutOfSceneList(mpComponent);
   mpComponent->emitAdded();
