@@ -40,6 +40,10 @@
 #include "Plotting/VariablesWidget.h"
 #include "Plotting/DiagramWindow.h"
 
+#include <QInputDialog>
+#include <QMessageBox>
+#include <QMenu>
+
 using namespace OMPlot;
 
 /*!
@@ -81,7 +85,8 @@ QString PlotWindowContainer::getUniqueName(QString name, int number)
   newName = name + QString::number(number);
 
   foreach (QMdiSubWindow *pWindow, subWindowList()) {
-    if (pWindow->widget()->windowTitle().compare(newName) == 0) {
+    QString oldName = pWindow->widget()->windowTitle();
+    if (oldName.compare(newName) == 0) {
       newName = getUniqueName(name, ++number);
       break;
     }
@@ -89,6 +94,19 @@ QString PlotWindowContainer::getUniqueName(QString name, int number)
   return newName;
 }
 
+bool PlotWindowContainer::isUniqueName(QString name)
+{
+  bool isUniqueName = true;
+  foreach (QMdiSubWindow *pWindow, subWindowList()) {
+    QString oldName = pWindow->widget()->windowTitle();
+    if (oldName.compare(name) == 0) {
+      isUniqueName = false;
+      break;
+    }
+  }
+  return isUniqueName;
+}
+
 /*!
  * \brief PlotWindowContainer::getCurrentWindow
  * Returns the current plot window, if the last window is animation, return null
@@ -283,6 +301,7 @@ void PlotWindowContainer::addPlotWindow(bool maximized)
                                          pPlottingPage->getHorizontalAxisTitleFontSizeSpinBox()->value(), pPlottingPage->getHorizontalAxisNumbersFontSizeSpinBox()->value(), pPlottingPage->getFooterFontSizeSpinBox()->value(),
                                          pPlottingPage->getLegendFontSizeSpinBox()->value());
     addCloseActionsToSubWindowSystemMenu(pSubWindow);
+    addRenameTabToSubWindowSystemMenu(pSubWindow);
     pSubWindow->setWindowIcon(QIcon(":/Resources/icons/plot-window.svg"));
     pPlotWindow->show();
     if (maximized) {
@@ -316,6 +335,7 @@ void PlotWindowContainer::addParametricPlotWindow()
                                          pPlottingPage->getHorizontalAxisTitleFontSizeSpinBox()->value(), pPlottingPage->getHorizontalAxisNumbersFontSizeSpinBox()->value(), pPlottingPage->getFooterFontSizeSpinBox()->value(),
                                          pPlottingPage->getLegendFontSizeSpinBox()->value());
     addCloseActionsToSubWindowSystemMenu(pSubWindow);
+    addRenameTabToSubWindowSystemMenu(pSubWindow);
     pSubWindow->setWindowIcon(QIcon(":/Resources/icons/parametric-plot-window.svg"));
     pPlotWindow->show();
   }
@@ -355,6 +375,7 @@ void PlotWindowContainer::addArrayPlotWindow(bool maximized)
                                          pPlottingPage->getHorizontalAxisTitleFontSizeSpinBox()->value(), pPlottingPage->getHorizontalAxisNumbersFontSizeSpinBox()->value(), pPlottingPage->getFooterFontSizeSpinBox()->value(),
                                          pPlottingPage->getLegendFontSizeSpinBox()->value());
     addCloseActionsToSubWindowSystemMenu(pSubWindow);
+    addRenameTabToSubWindowSystemMenu(pSubWindow);
     pSubWindow->setWindowIcon(QIcon(":/Resources/icons/array-plot-window.svg"));
     pPlotWindow->show();
     if (maximized) {
@@ -392,6 +413,7 @@ PlotWindow* PlotWindowContainer::addInteractivePlotWindow(bool maximized, QStrin
                                          pPlottingPage->getLegendFontSizeSpinBox()->value());
     pPlotWindow->setSubWindow(pSubWindow);
     addCloseActionsToSubWindowSystemMenu(pSubWindow);
+    addRenameTabToSubWindowSystemMenu(pSubWindow);
     pSubWindow->setWindowIcon(QIcon(":/Resources/icons/interaction.svg"));
     pPlotWindow->show();
     if (maximized) {
@@ -434,6 +456,7 @@ void PlotWindowContainer::addArrayParametricPlotWindow()
                                          pPlottingPage->getHorizontalAxisTitleFontSizeSpinBox()->value(), pPlottingPage->getHorizontalAxisNumbersFontSizeSpinBox()->value(), pPlottingPage->getFooterFontSizeSpinBox()->value(),
                                          pPlottingPage->getLegendFontSizeSpinBox()->value());
     addCloseActionsToSubWindowSystemMenu(pSubWindow);
+    addRenameTabToSubWindowSystemMenu(pSubWindow);
     pSubWindow->setWindowIcon(QIcon(":/Resources/icons/array-parametric-plot-window.svg"));
     pPlotWindow->show();
   }
@@ -454,6 +477,7 @@ void PlotWindowContainer::addAnimationWindow(bool maximized)
   pAnimationWindow->setWindowTitle(getUniqueName("Animation : "));
   QMdiSubWindow *pSubWindow = addSubWindow(pAnimationWindow);
   addCloseActionsToSubWindowSystemMenu(pSubWindow);
+  addRenameTabToSubWindowSystemMenu(pSubWindow);
   pSubWindow->setWindowIcon(QIcon(":/Resources/icons/animation.svg"));
   pAnimationWindow->show();
   if (maximized) {
@@ -481,6 +505,7 @@ void PlotWindowContainer::addDiagramWindow(ModelWidget *pModelWidget, bool maxim
   if (!pSubWindow) {
     pSubWindow = addSubWindow(mpDiagramWindow);
     addCloseActionsToSubWindowSystemMenu(pSubWindow);
+    addRenameTabToSubWindowSystemMenu(pSubWindow);
     pSubWindow->setWindowIcon(QIcon(":/Resources/icons/modeling.png"));
   }
   mpDiagramWindow->show();
@@ -501,6 +526,31 @@ void PlotWindowContainer::removeInteractivePlotWindow()
   MainWindow::instance()->getVariablesWidget()->getVariablesTreeModel()->removeVariableTreeItem(owner);
 }
 
+/*!
+ * \brief PlotWindowContainer::renamePlotWindow
+ * Enables the renaming of an existing plot window using right click.
+ */
+void PlotWindowContainer::renamePlotWindow()
+{
+  QAction *pAction = qobject_cast<QAction*>(sender());
+  QMdiSubWindow *pMdiSubWindow = qobject_cast<QMdiSubWindow*>(pAction->parent());
+  bool okPressed = false;
+  QString text = QInputDialog::getText(this,
+                                       tr("Name Plot Tab"),
+                                       tr("Name:"),
+                                       QLineEdit::Normal,
+                                       pMdiSubWindow->windowTitle(), &okPressed);
+  if (okPressed && !text.isEmpty()) {
+    if (isUniqueName(text)) {
+      pMdiSubWindow->widget()->setWindowTitle(text);
+    }
+    else /* Name it the users name + 1. Avoids another popup. */{
+      QString uniqueName = getUniqueName(text, 1);
+      pMdiSubWindow->widget()->setWindowTitle(uniqueName);
+    }
+  }
+}
+
 /*!
  * \brief PlotWindowContainer::clearPlotWindow
  * Clears the plot window
@@ -628,3 +678,16 @@ void PlotWindowContainer::updatePlotWindows(QString variable)
     } // is plotWidget
   }
 }
+
+/*!
+ * \brief addRenameTabToSubWindowSystemMenu
+ * Adds the rename tab action to the sub system menu
+ */
+void PlotWindowContainer::addRenameTabToSubWindowSystemMenu(QMdiSubWindow *pMdiSubWindow)
+{
+  QAction *pRenamePlotWindowAction = new QAction(tr("Rename"), pMdiSubWindow);
+  pRenamePlotWindowAction->setStatusTip(tr("Renames the plot tab"));
+  connect(pRenamePlotWindowAction, SIGNAL(triggered()), SLOT(renamePlotWindow()));
+  QMenu *pMenu = pMdiSubWindow->systemMenu();
+  pMenu->addAction(pRenamePlotWindowAction);
+}
