@@ -31,7 +31,7 @@
  * @author Adeel Asghar <adeel.asghar@liu.se>
  */
 
-#ifdef WIN32
+#if defined(_WIN32)
 #include <winsock2.h>
 #else
 #include <sys/socket.h>
@@ -53,6 +53,10 @@
 #include "Animation/AnimationWindow.h"
 #endif
 
+#include <QDockWidget>
+#include <QMessageBox>
+#include <QDesktopWidget>
+
 TLMCoSimulationDialog::TLMCoSimulationDialog(QWidget *pParent)
   : QDialog(pParent)
 {
@@ -308,7 +312,7 @@ TLMCoSimulationOptions TLMCoSimulationDialog::createTLMCoSimulationOptions()
 #define MAXHOSTNAME 1024
     char myname[MAXHOSTNAME+1];
     struct hostent *hp;
-#ifdef WIN32
+#if defined(_WIN32)
     WSADATA ws;
     int d;
     d = WSAStartup(0x0101,&ws);
@@ -340,14 +344,14 @@ void TLMCoSimulationDialog::browseTLMPluginPath()
 {
   mpTLMPluginPathTextBox->setText(StringHandler::getExistingDirectory(this, QString(Helper::applicationName).append(" - ").append(Helper::chooseDirectory), NULL));
   if (mpManagerProcessTextBox->text().isEmpty()) {
-#ifdef WIN32
+#if defined(_WIN32)
     mpManagerProcessTextBox->setText(mpTLMPluginPathTextBox->text() + "/tlmmanager.exe");
 #else
     mpManagerProcessTextBox->setText(mpTLMPluginPathTextBox->text() + "/tlmmanager");
 #endif
   }
   if (mpMonitorProcessTextBox->text().isEmpty()) {
-#ifdef WIN32
+#if defined(_WIN32)
     mpMonitorProcessTextBox->setText(mpTLMPluginPathTextBox->text() + "/tlmmonitor.exe");
 #else
     mpMonitorProcessTextBox->setText(mpTLMPluginPathTextBox->text() + "/tlmmonitor");
