@@ -73,7 +73,7 @@ namespace IAEX
     Q_OBJECT
 
   public:
-    typedef vector<DocumentView*> observers_t;
+    typedef std::vector<DocumentView*> observers_t;
 
     CellDocument(CellApplication *a, const QString filename, int readmode = READMODE_NORMAL);
     virtual ~CellDocument();
@@ -138,7 +138,7 @@ namespace IAEX
     CellCursor *getCursor();
     Factory *cellFactory();
     Cell* getMainCell();        // Added 2006-08-24 AF
-    vector<Cell*> getSelection();
+    std::vector<Cell*> getSelection();
 
     //Command
     void executeCommand(Command *cmd);
@@ -205,7 +205,7 @@ namespace IAEX
     CellCursor *current_;
     Factory *factory_;
 
-    vector<Cell*> selectedCells_;
+    std::vector<Cell*> selectedCells_;
 
   public:
     observers_t observers_;
