@@ -143,7 +143,11 @@ namespace IAEX {
         max /= 10;
         ++digits;
     }
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
+    int space = 3 + fontMetrics().horizontalAdvance(QLatin1Char('9')) * digits;
+#else // QT_VERSION_CHECK
     int space = 3 + fontMetrics().width(QLatin1Char('9')) * digits;
+#endif // QT_VERSION_CHECK
 
     return space;
   }
@@ -1233,7 +1237,7 @@ namespace IAEX {
   QString GraphCell::ChapterCounter()
   {
     if( chaptercounter_->toPlainText().isEmpty() )
-      return QString::null;
+      return QString();
 
     return chaptercounter_->toPlainText();
   }
@@ -1248,7 +1252,7 @@ namespace IAEX {
   QString GraphCell::ChapterCounterHtml()
   {
     if( chaptercounter_->toPlainText().isEmpty() )
-      return QString::null;
+      return QString();
 
     return chaptercounter_->toHtml();
   }
@@ -1288,7 +1292,7 @@ namespace IAEX {
     }
     catch(...)
     {
-      // qDebug() << "setReadOnly: crash" << endl;
+      // qDebug() << "setReadOnly: crash" << Qt::endl;
     }
   }
 
@@ -1487,7 +1491,11 @@ namespace IAEX {
       lst << legendPosition;
       lst << footer;
       lst << autoScale;
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+      lst << QString(variables).split(" ", Qt::SkipEmptyParts);
+#else // QT_VERSION_CHECK
       lst << QString(variables).split(" ", QString::SkipEmptyParts);
+#endif // QT_VERSION_CHECK
       emit pGraphCell->plotVariables(lst);  // yes we need to use signal & slot since command is executed in different thread.
     }
   }
@@ -1536,7 +1544,11 @@ namespace IAEX {
   * highlightning is used in the output cell.
   *
   */
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+  QRecursiveMutex* guard = new QRecursiveMutex();
+#else // QT_VERSION_CHECK
   QMutex* guard = new QMutex(QMutex::Recursive);
+#endif // QT_VERSION_CHECK
 
   void GraphCell::eval()
   {
@@ -1777,7 +1789,7 @@ namespace IAEX {
   InputCellDelegate *GraphCell::getDelegate()
   {
     if(!hasDelegate())
-      throw runtime_error("No delegate.");
+      throw std::runtime_error("No delegate.");
 
     return delegate_;
   }
