@@ -473,8 +473,7 @@ namespace IAEX
     else
     {
       // 2006-01-30 AF, add message box
-      QString msg = "No Output style defened, please define a Output style in stylesheet.xml";
-      QMessageBox::warning( 0, "Warning", msg, "OK" );
+      QMessageBox::warning( 0, tr("Warning"), tr("No Output style defined, please define an Output style in stylesheet.xml"), "OK" );
     }
 
     QTextCursor cursor = output_->textCursor();
@@ -825,7 +824,7 @@ namespace IAEX
   QString InputCell::ChapterCounter()
   {
     if( chaptercounter_->toPlainText().isEmpty() )
-      return QString::null;
+      return QString();
 
     return chaptercounter_->toPlainText();
   }
@@ -840,7 +839,7 @@ namespace IAEX
   QString InputCell::ChapterCounterHtml()
   {
     if( chaptercounter_->toPlainText().isEmpty() )
-      return QString::null;
+      return QString();
 
     return chaptercounter_->toHtml();
   }
@@ -1074,9 +1073,8 @@ namespace IAEX
       // 2006-02-17 AF, set text '{evaluation expression}" during
       // evaluation of expressiuon
       output_->selectAll();
-      output_->textCursor().insertText( "{evaluating expression}" );
+      output_->textCursor().insertText( tr("{evaluating expression}") );
       setOutputStyle();
-      //output_->setPlainText( "{evaluating expression}" );
       output_->update();
       QCoreApplication::processEvents();
       delegate()->evalExpression(expr);
@@ -1116,7 +1114,7 @@ namespace IAEX
       emit textChanged(true);
     }
     else
-      cout << "Not delegate on inputcell" << endl;
+      std::cout << "Not delegate on inputcell" << std::endl;
 
     input_->blockSignals(false);
     output_->blockSignals(false);
@@ -1147,7 +1145,6 @@ namespace IAEX
    */
   void InputCell::nextCommand()
   {
-    qDebug("Next Command");
     CommandCompletion *commandcompletion = CommandCompletion::instance( "commands.xml" );
     QTextCursor cursor = input_->textCursor();
 
@@ -1163,7 +1160,6 @@ namespace IAEX
    */
   void InputCell::nextField()
   {
-    qDebug("Next Field");
     CommandCompletion *commandcompletion = CommandCompletion::instance( "commands.xml" );
     QTextCursor cursor = input_->textCursor();
 
@@ -1223,7 +1219,7 @@ namespace IAEX
   InputCellDelegate *InputCell::delegate()
   {
     if(!hasDelegate())
-      throw runtime_error("No delegate.");
+      throw std::runtime_error("No delegate.");
 
     return delegate_;
   }
