@@ -80,54 +80,21 @@
 
 #include "treeview.h"
 #include "stylesheet.h"
-#include "commandcompletion.h"
-#include "highlighterthread.h"
 #include "omcinteractiveenvironment.h"
-#include "indent.h"
-
-
 
 namespace IAEX {
-  /*!
-  * \class SleeperThread
-  * \author Anders Ferström
-  *
-  * \brief Extends QThread. A small trick to get access to protected
-  * function in QThread.
-  */
-  class SleeperThread : public QThread
-  {
-  public:
-    static void msleep(unsigned long msecs)
-    {
-      QThread::msleep(msecs);
-    }
-  };
-
-
   /*!
   * \brief Extends QTextEdit. Mostly so I can catch when a user
   * clicks on the editor
   */
   MyTextEdit3::MyTextEdit3(QWidget *parent)
-    : QTextBrowser(parent),
-    inCommand(false),
-    stopHighlighter(false), autoIndent(true)
+    : QTextBrowser(parent)
   {
 
   }
 
   MyTextEdit3::~MyTextEdit3()
   {
-    for(QMap<int, IndentationState*>::iterator i = indentationStates.begin(); i != indentationStates.end(); ++i)
-    {
-      delete i.value();
-    }
-  }
-
-  bool MyTextEdit3::isStopingHighlighter()
-  {
-    return stopHighlighter;
   }
 
   /*!
@@ -136,8 +103,6 @@ namespace IAEX {
   */
   void MyTextEdit3::mousePressEvent(QMouseEvent *event)
   {
-    stopHighlighter = false;
-    inCommand = false;
     QTextBrowser::mousePressEvent(event);
 
     if( event->modifiers() == Qt::ShiftModifier ||
@@ -182,80 +147,35 @@ namespace IAEX {
     if( event->modifiers() == Qt::ShiftModifier &&
       (event->key() == Qt::Key_Return || event->key() == Qt::Key_Enter) )
     {
-      inCommand = false;
-      stopHighlighter = false;
-
       event->accept();
       emit eval();
     }
-    // COMMAND COMPLETION, key: SHIFT + TAB (= BACKTAB) || CTRL + SPACE
-    else if( (event->modifiers() == Qt::ShiftModifier && event->key() == Qt::Key_Backtab ) ||
-      (event->modifiers() == Qt::ControlModifier && event->key() == Qt::Key_Space) )
-    {
-      stopHighlighter = false;
-
-      event->accept();
-      if( inCommand )
-      {
-        emit nextCommand();
-      }
-      else
-      {
-        inCommand = true;
-        emit command();
-      }
-    }
-    // COMMAND COMPLETION- NEXT FIELD, key: CTRL + TAB
-    else if( event->modifiers() == Qt::ControlModifier &&
-      event->key() == Qt::Key_Tab )
-    {
-      stopHighlighter = false;
-
-      event->accept();
-      inCommand = false;
-      emit nextField();
-    }
     // BACKSPACE, DELETE
     else if( event->key() == Qt::Key_Backspace ||
       event->key() == Qt::Key_Delete )
     {
-      inCommand = false;
-      stopHighlighter = true;
-
       QTextBrowser::keyPressEvent( event );
     }
     // ALT+ENTER (ignore)
     else if( event->modifiers() == Qt::AltModifier &&
       ( event->key() == Qt::Key_Enter || event->key() == Qt::Key_Return ))
     {
-      inCommand = false;
-      stopHighlighter = false;
-
       event->ignore();
     }
     // PAGE UP (ignore)
     else if( event->key() == Qt::Key_PageUp )
     {
-      inCommand = false;
-      stopHighlighter = false;
-
       event->ignore();
     }
     // PAGE DOWN (ignore)
     else if( event->key() == Qt::Key_PageDown )
     {
-      inCommand = false;
-      stopHighlighter = false;
-
       event->ignore();
     }
     // CTRL+C
     else if( event->modifiers() == Qt::ControlModifier &&
       event->key() == Qt::Key_C )
     {
-      inCommand = false;
-      stopHighlighter = false;
-
       event->ignore();
       emit forwardAction( 1 );
     }
@@ -263,9 +183,6 @@ namespace IAEX {
     else if( event->modifiers() == Qt::ControlModifier &&
       event->key() == Qt::Key_X )
     {
-      inCommand = false;
-      stopHighlighter = false;
-
       event->ignore();
       emit forwardAction( 2 );
     }
@@ -273,33 +190,11 @@ namespace IAEX {
     else if( event->modifiers() == Qt::ControlModifier &&
       event->key() == Qt::Key_V )
     {
-      inCommand = false;
-      stopHighlighter = false;
-
       event->ignore();
       emit forwardAction( 3 );
     }
-    else if(event->modifiers() == Qt::ControlModifier && event->key() == Qt::Key_W)
-    {
-      inCommand = false;
-      stopHighlighter = false;
-      indentText();
-      event->ignore();
-      //      QTextBrowser::keyPressEvent( event );
-      //      update();
-
-    }
-
-    else if(event->modifiers() == Qt::ControlModifier && event->key() == Qt::Key_E)
-    {
-      inCommand = false;
-      stopHighlighter = false;
-      indentText();
-    }
     else if(event->modifiers() == Qt::ControlModifier && event->key() == Qt::Key_K)
     {
-      inCommand = false;
-      stopHighlighter = true;
       QTextCursor tc(textCursor());
       int i = toPlainText().indexOf(QRegExp("\\n|$"), tc.position());
 
@@ -314,75 +209,14 @@ namespace IAEX {
     // TAB
     else if( event->key() == Qt::Key_Tab )
     {
-      inCommand = false;
-      stopHighlighter = false;
       textCursor().insertText( "  " );
     }
-    else if( event->key() == Qt::Key_Enter || event->key() == Qt::Key_Return )
-    {
-      if(autoIndent)
-      {
-        QTextCursor t(textCursor());
-        QString tmp, tmp2;
-        int k2 = t.blockNumber();
-        QTextBlock b = t.block();
-        int k = b.userState();
-        int prevLevel = b.text().indexOf(QRegExp("\\S"));
-
-        while(k2 >= 0 && !indentationStates.contains(k))
-        {
-          tmp = b.text() + "\n" + tmp;
-          b = b.previous();
-          --k2;
-          k = b.userState();
-        }
-        Indent i(tmp);
-        if(indentationStates.contains(k))
-        {
-          IndentationState* s = indentationStates[k];
-          i.ism.level = s->level;
-          i.ism.equation = s->equation;
-          i.ism.equationSection = s->equationSection;
-          i.ism.lMod = s->lMod;
-          i.ism.loopBlock = s->loopBlock;
-          i.ism.nextMod = s->nextMod;
-          i.ism.skipNext = s->skipNext;
-          i.ism.state = s->state;
-          i.current = s->current;
-          i.next = s->next;
-        }
-
-        i.indentedText();
-
-        if(prevLevel > 2*i.level())
-        {
-          t.setPosition(t.block().position());
-          t.setPosition(t.block().position() + prevLevel-2*(i.level()),QTextCursor::KeepAnchor);
-          if(!t.selection().toPlainText().trimmed().size())
-            t.insertText("");
-          t.setPosition(t.block().position() + t.block().length() -1);
-        }
-
-        QTextBrowser::keyPressEvent(event);
-        t.insertText(QString(2*i.level(), ' '));
-      }
-      else
-        QTextBrowser::keyPressEvent(event);
-    }
     else
     {
-      inCommand = false;
-      stopHighlighter = false;
       QTextBrowser::keyPressEvent( event );
     }
 
     updatePosition();
-
-  }
-
-  void MyTextEdit3::setAutoIndent(bool b)
-  {
-    autoIndent = b;
   }
 
   void MyTextEdit3::setModified()
@@ -419,35 +253,6 @@ namespace IAEX {
       emit setState(Modified_l);
   }
 
-  void MyTextEdit3::goToPos(const QUrl& u)
-  {
-    QRegExp e("\\-|:");
-    int r=u.toString().section(e, 0,0).toInt();
-    int c=u.toString().section(e, 1,1).toInt();
-    int r2=u.toString().section(e, 2,2).toInt();
-    int c2=u.toString().section(e, 3,3).toInt();
-
-    int p = 0;
-    for(int i = 1; i < r; ++i)
-      p = toPlainText().indexOf("\n", p)+1;
-    p += (c-1);
-
-    QTextCursor tc(textCursor());
-    tc.setPosition(p);
-
-    int p2 = 0;
-    if(r2 > 0)
-    {
-      for(int i = 1; i < r2; ++i)
-        p2 = toPlainText().indexOf("\n", p2)+1;
-      p2 += (c2-1);
-      tc.setPosition(p2, QTextCursor::KeepAnchor);
-    }
-    setTextCursor(tc);
-    updatePos(r, c);
-    setFocus(Qt::MouseFocusReason);
-  }
-
   void MyAction1::triggered2()
   {
     emit urlClicked(QUrl(text()));
@@ -477,10 +282,6 @@ namespace IAEX {
     createLatexCell();
     createOutputCell();
 
-    //connect(input_, SIGNAL(showVariableButton(bool)), this, SLOT(showVariableButton(bool)));
-
-    //connect(output_, SIGNAL(anchorClicked(const QUrl&)), input_, SLOT(goToPos(const QUrl&)));
-
     imageFile=0;
   }
 
@@ -490,30 +291,11 @@ namespace IAEX {
   */
   LatexCell::~LatexCell()
   {
-    //2006-01-05 AF, check if input texteditor is in the highlighter,
-    //if it is - wait for 60 ms and check again.
-    HighlighterThread *thread = HighlighterThread::instance();
-    int sleepTime = 0;
-    bool firstTime = true;
-    while( thread->haveEditor( input_ ) )
-    {
-      if( firstTime )
-      {
-        thread->removeEditor( input_ );
-        firstTime = false;
-      }
-
-      SleeperThread::msleep( 60 );
-      sleepTime++;
-
-      if( sleepTime > 100 )
-        break;
-    }
-
     delete input_;
     delete output_;
-    if(imageFile)
+    if(imageFile) {
       delete imageFile;
+    }
   }
 
  void LatexCell::createLatexCell()
@@ -542,10 +324,6 @@ namespace IAEX {
     connect( input_, SIGNAL( clickOnCell() ), this, SLOT( clickEvent() ));
     connect( input_, SIGNAL( wheelMove(QWheelEvent*) ), this, SLOT( wheelEvent(QWheelEvent*) ));
     connect( input_, SIGNAL( eval() ), this, SLOT( eval() ));
-    connect( input_, SIGNAL( command() ), this, SLOT( command() ));
-    connect( input_, SIGNAL( nextCommand() ), this, SLOT( nextCommand() ));
-    connect( input_, SIGNAL( nextField() ), this, SLOT( nextField() ));
-    connect( input_, SIGNAL( nextField() ), this, SLOT( nextField() ));
 
     //connect( input_, SIGNAL( textChanged() ), this, SLOT( addToHighlighter() ));
     connect( input_, SIGNAL( currentCharFormatChanged(const QTextCharFormat &) ),
@@ -591,40 +369,6 @@ namespace IAEX {
     output_->hide();
   }
 
-  bool MyTextEdit3::lessIndented(QString s)
-  {
-    QRegExp l("\\b(equation|algorithm|public|protected|else|elseif)\\b");
-    return s.indexOf(l) >= 0;
-  }
-
-  int MyTextEdit3::indentationLevel(QString s, bool includeNegative)
-  {
-    QRegExp e1("\\b(model|class|type|connector|block|record|function|record|for|when|package|if)\\b");
-    QRegExp e1b("end\\s+(model|class|type|connector|block|record|function|record|for|when|package|if)\\b");
-    QRegExp e2("\\b(end|then)\\b");
-
-    QRegExp newLineEnd("^end\\b");
-
-    //    return s.count(e1) - includeNegative?(s.count(e2) + s.count(e1b)):0;
-    if(includeNegative)
-      return s.count(e1) - s.count(e2) - s.count(e1b);// - s.count(lessIndented);
-    else
-      return s.count(e1) - s.count(e1b);//- s.count(lessIndented);
-  }
-
-  void MyTextEdit3::indentText()
-  {
-    Indent a(toPlainText());
-    setText(a.indentedText(&indentationStates));
-
-    int i = 1;
-    for(QTextBlock b =this->document()->begin(); b != this->document()->end(); b = b.next())
-    {
-      b.setUserState(++i);
-    }
-    emit textChanged();
-  }
-
   /*!
   * \author Anders Fernström
   * \date 2006-04-21
@@ -648,8 +392,7 @@ namespace IAEX {
     else
     {
       // 2006-01-30 AF, add message box
-      QString msg = "No Output style defened, please define a Output style in stylesheet.xml";
-      QMessageBox::warning( 0, "Warning", msg, "OK" );
+      QMessageBox::warning( 0, tr("Warning"), tr("No Output style defined, please define an Output style in stylesheet.xml"), "OK" );
     }
 
     QTextCursor cursor = output_->textCursor();
@@ -912,7 +655,7 @@ namespace IAEX {
   QString LatexCell::ChapterCounter()
   {
     if( chaptercounter_->toPlainText().isEmpty() )
-      return QString::null;
+      return QString();
 
     return chaptercounter_->toPlainText();
   }
@@ -924,7 +667,7 @@ namespace IAEX {
   QString LatexCell::ChapterCounterHtml()
   {
     if( chaptercounter_->toPlainText().isEmpty() )
-      return QString::null;
+      return QString();
 
     return chaptercounter_->toHtml();
   }
@@ -959,7 +702,7 @@ namespace IAEX {
     }
     catch(...)
     {
-      // qDebug() << "setReadOnly: crash" << endl;
+      // qDebug() << "setReadOnly: crash" << Qt::endl;
     }
   }
 
@@ -1108,7 +851,7 @@ namespace IAEX {
   */
 
 
-void LatexCell::eval()
+void LatexCell::eval(bool silent)
 {
 
     /*! Steps to generate the document output
@@ -1170,7 +913,7 @@ void LatexCell::eval()
     {
         expr.replace("\\begin{document}","\\begin{document} \\thispagestyle{empty}");
         if (!expr.contains("\\begin{document}")) {
-            expr.prepend("\\documentclass{article}\\begin{document}\\thispagestyle{empty}");
+            expr.prepend("\\documentclass[12pt]{article}\\usepackage[utf8]{inputenc}\\usepackage{amsmath}\\usepackage{amsfonts}\\usepackage{amssymb}\\begin{document}\\thispagestyle{empty}");
             expr.append("\\end{document}");
         }
         QFile file(Tex);
@@ -1191,10 +934,12 @@ void LatexCell::eval()
         /* Check for latex is installed */
         if (Latexversion.isEmpty())
         {
-            QMessageBox::warning( 0, "Error", "Latex is not installed in your System, This cell cannot be evaluated", "OK" );
+          setState(Error_l);
+          if (!silent)
+            QMessageBox::warning( 0, tr("Error"), tr("Latex is not installed in your System. This cell cannot be evaluated."), "OK" );
         }
         /*Generate the DVI file from tex through latex */
-        if (!Latexversion.isEmpty())
+        else
         {
             process->start("latex", QStringList() << "-halt-on-error" << Tex);
             process->waitForFinished();
@@ -1219,11 +964,13 @@ void LatexCell::eval()
                 input_->clear();
                 input_->textCursor().insertText(texoutput);
                 setClosed(false);
+                setState(Error_l);
             }
             else
             {
                 setdvi=true;
                 setClosed(true);
+                setState(Finished_l);
             }
 
         }
@@ -1234,7 +981,7 @@ void LatexCell::eval()
             // check for number of pages tex script generates
             if(setpage==true)
             {
-                process->start("dvipng",QStringList() << "-T" << "tight" << Dvi << "-o" << Png);
+                process->start("dvipng",QStringList() << "-T" << "tight" << "-bg" << "transparent" << Dvi << "-o" << Png);
                 process->waitForFinished();
                 QFileInfo checkpng(Png);
                 if(!checkpng.exists())
@@ -1242,19 +989,22 @@ void LatexCell::eval()
                     input_->clear();
                     input_->textCursor().insertText("Error:Problem in finding dvipng executable");
                     setClosed(false);
-
+                    setState(Error_l);
                 }
                 else
                 {
                     input_->clear();
-                    input_->textCursor().insertImage(Png);
+                    QFileInfo fi(Png);
+                    QString res = fi.fileName();
+                    QImage img(res, "PNG");
+                    textEdit()->document()->addResource(QTextDocument::ImageResource, QUrl(res), img);
+                    input_->textCursor().insertImage(res);
                     setClosed(true);
                 }
             }
             else
             {
-
-                QMessageBox::warning( 0, "Warning", "Maximum of 1 page document generation is supported per Latexcell, The script generates more than 1 page", "OK" );
+                QMessageBox::warning( 0, tr("Warning"), tr("Maximum of 1 page document generation is supported per Latexcell.\nThe script generates more than 1 page."), "OK" );
             }
         }
     }
@@ -1262,8 +1012,9 @@ void LatexCell::eval()
     {
         //qDebug()<< "Empty cells can't be evaluated";
         input_->clear();
-        input_->textCursor().insertText("Message: Empty Latex Cells cannot be Evaluated");
+        input_->textCursor().insertText(tr("Message: Empty Latex Cells cannot be evaluated."));
         setClosed(false);
+        setState(Error_l);
     }
     input_->blockSignals(false);
     output_->blockSignals(false);
@@ -1276,61 +1027,20 @@ void LatexCell::setState(int state_)
     switch(state_)
     {
     case Modified_l:
-      emit newState("Ready");
+      emit newState(tr("Ready"));
       break;
     case Eval_l:
-      emit newState("Evaluating...");
+      emit newState(tr("Evaluating..."));
       break;
     case Finished_l:
-      emit newState("Done");
+      emit newState(tr("Done"));
       break;
     case Error_l:
-      emit newState("Error");
+      emit newState(tr("Error"));
       break;
     }
   }
 
-  /*!
-  *\brief Get/Insert the command that match the last word in the
-  * input editor.
-  */
-  void LatexCell::command()
-  {
-    CommandCompletion *commandcompletion = CommandCompletion::instance( "commands.xml" );
-    QTextCursor cursor = input_->textCursor();
-
-    if( commandcompletion->insertCommand( cursor ))
-      input_->setTextCursor( cursor );
-  }
-
-  /*!
-  *\brief Get/Insert the next command that match the last word in
-  * the input editor.
-  */
-  void LatexCell::nextCommand()
-  {
-    CommandCompletion *commandcompletion = CommandCompletion::instance( "commands.xml" );
-    QTextCursor cursor = input_->textCursor();
-
-    if( commandcompletion->nextCommand( cursor ))
-      input_->setTextCursor( cursor );
-
-  }
-
-  /*!
-  *\brief Select the next field in the command, if any exists
-  */
-  void LatexCell::nextField()
-  {
-    CommandCompletion *commandcompletion = CommandCompletion::instance( "commands.xml" );
-    QTextCursor cursor = input_->textCursor();
-
-    if( commandcompletion->nextField( cursor ))
-      input_->setTextCursor( cursor );
-
-  }
-
-
   /*!
   * \brief set the correct style if the charFormat is changed and the
   * cell is empty. This is done because otherwise the style is lost if
@@ -1376,7 +1086,6 @@ void LatexCell::setState(int state_)
     {
       output_->clear();
       evaluated_ = false;
-      // PORT >> layout_->remove(output_);
       layout_->removeWidget(output_);
     }
 
@@ -1399,7 +1108,6 @@ void LatexCell::setState(int state_)
 
   void LatexCell::mouseDoubleClickEvent(QMouseEvent *)
   {
-    // PORT >>if(treeView()->hasMouse())
     if(treeView()->testAttribute(Qt::WA_UnderMouse))
     {
       setClosed(!closed_);
@@ -1408,7 +1116,6 @@ void LatexCell::setState(int state_)
 
   void LatexCell::accept(Visitor &v)
   {
-
     v.visitLatexCellNodeBefore(this);
 
     if(hasChilds())
