@@ -70,7 +70,6 @@ extern "C" {
 
 #include <locale.h>
 
-using namespace std;
 using namespace IAEX;
 
 int main(int argc, char *argv[])
@@ -95,7 +94,7 @@ int main(int argc, char *argv[])
     CellApplication a(argc, argv, threadData);
     return a.exec();
   }
-  catch(exception &e)
+  catch(std::exception &e)
   {
     // 2006-01-30 AF, add message box
     QString msg = QString("In main(), exception: \n") + e.what();
