@@ -61,6 +61,7 @@
 #include "cellcursor.h"
 #include "inputcell.h"
 #include "graphcell.h"
+#include "latexcell.h"
 
 
 namespace IAEX
@@ -100,6 +101,18 @@ namespace IAEX
           graphcell->textEdit()->cut();
       }
 
+      else if( typeid(LatexCell) == typeid(*cell) )
+      {
+        LatexCell *latexcell = dynamic_cast<LatexCell*>(cell);
+        if( latexcell->textEditOutput()->hasFocus() &&
+          latexcell->isEvaluated() )
+        {
+          latexcell->textEditOutput()->cut();
+        }
+        else
+          latexcell->textEdit()->cut();
+      }
+
 
       else
       {
@@ -147,6 +160,17 @@ namespace IAEX
         else
           graphcell->textEdit()->copy();
       }
+      else if( typeid(LatexCell) == typeid(*cell) )
+      {
+        LatexCell *latexcell = dynamic_cast<LatexCell*>(cell);
+        if( latexcell->textEditOutput()->hasFocus() &&
+          latexcell->isEvaluated() )
+        {
+          latexcell->textEditOutput()->copy();
+        }
+        else
+          latexcell->textEdit()->copy();
+      }
       else
       {
         QTextEdit *editor = cell->textEdit();
@@ -168,11 +192,38 @@ namespace IAEX
      */
   void TextCursorPasteText::execute()
   {
-    QTextEdit *editor = document()->getCursor()->currentCell()->textEdit();
+      Cell *cell = document()->getCursor()->currentCell();
+      if( cell )
+      {
+        if( typeid(LatexCell) == typeid(*cell) )
+        {
+          LatexCell *latexcell = dynamic_cast<LatexCell*>(cell);
+          if( latexcell->textEditOutput()->hasFocus() &&
+            latexcell->isEvaluated() )
+          {
+            latexcell->textEditOutput()->paste();
+          }
+          else
+          {
+            latexcell->textEdit()->paste();
+          }
+        }
+        else
+        {
+          QTextEdit *editor = cell->textEdit();
+          if( editor )
+          {
+            editor->paste();
+          }
+        }
+
+      }
+
+  /*  QTextEdit *editor = document()->getCursor()->currentCell()->textEdit();
     if( editor )
     {
       editor->paste();
-    }
+    }*/
   }
 
 
@@ -319,8 +370,7 @@ namespace IAEX
         if( oldStretch == cursor.charFormat().font().stretch() )
         {
           // 2006-01-30 AF, add message box
-          QString msg = "QT was unable to stretch the font";
-          QMessageBox::warning( 0, "Warning", msg, "OK" );
+          QMessageBox::warning( 0, QObject::tr("Warning"), QObject::tr("QT was unable to stretch the font"), "OK" );
         }
       }
     }
@@ -568,8 +618,8 @@ namespace IAEX
       }
       else
       {
-        string str = string("Could not open image: ") + filepath_.toStdString().c_str();
-        throw runtime_error( str.c_str() );
+        std::string str = std::string("Could not open image: ") + filepath_.toStdString().c_str();
+        throw std::runtime_error( str.c_str() );
       }
     }
   }
