@@ -1,20 +1,21 @@
 /*
  * This file is part of OpenModelica.
  *
- * Copyright (c) 1998-CurrentYear, Linkoping University,
- * Department of Computer and Information Science,
- * SE-58183 Linkoping, Sweden.
+ * Copyright (c) 1998-CurrentYear, Open Source Modelica Consortium (OSMC),
+ * c/o Linköpings universitet, Department of Computer and Information Science,
+ * SE-58183 Linköping, Sweden.
  *
  * All rights reserved.
  *
- * THIS PROGRAM IS PROVIDED UNDER THE TERMS OF GPL VERSION 3
- * AND THIS OSMC PUBLIC LICENSE (OSMC-PL).
- * ANY USE, REPRODUCTION OR DISTRIBUTION OF THIS PROGRAM CONSTITUTES RECIPIENT'S
- * ACCEPTANCE OF THE OSMC PUBLIC LICENSE.
+ * THIS PROGRAM IS PROVIDED UNDER THE TERMS OF GPL VERSION 3 LICENSE OR
+ * THIS OSMC PUBLIC LICENSE (OSMC-PL) VERSION 1.2.
+ * ANY USE, REPRODUCTION OR DISTRIBUTION OF THIS PROGRAM CONSTITUTES
+ * RECIPIENT'S ACCEPTANCE OF THE OSMC PUBLIC LICENSE OR THE GPL VERSION 3,
+ * ACCORDING TO RECIPIENTS CHOICE.
  *
  * The OpenModelica software and the Open Source Modelica
  * Consortium (OSMC) Public License (OSMC-PL) are obtained
- * from Linkoping University, either from the above address,
+ * from OSMC, either from the above address,
  * from the URLs: http://www.ida.liu.se/projects/OpenModelica or
  * http://www.openmodelica.org, and in the OpenModelica distribution.
  * GNU version 3 is obtained from: http://www.gnu.org/copyleft/gpl.html.
@@ -22,13 +23,10 @@
  * This program is distributed WITHOUT ANY WARRANTY; without
  * even the implied warranty of  MERCHANTABILITY or FITNESS
  * FOR A PARTICULAR PURPOSE, EXCEPT AS EXPRESSLY SET FORTH
- * IN THE BY RECIPIENT SELECTED SUBSIDIARY LICENSE CONDITIONS
- * OF OSMC-PL.
+ * IN THE BY RECIPIENT SELECTED SUBSIDIARY LICENSE CONDITIONS OF OSMC-PL.
  *
  * See the full OSMC Public License conditions for more details.
  *
- * Main Author 2011: Adeel Asghar
- *
  */
 
 #ifndef PLOTCURVE_H
@@ -42,24 +40,27 @@ namespace OMPlot
 class PlotCurve : public QwtPlotCurve
 {
 private:
-  QString mName;
   QString mNameStructure;
   QString mFileName;
   QString mAbsoluteFilePath;
   QString mXVariable;
   QString mYVariable;
   bool mCustomColor;
-  QString mUnit;
-  QString mDisplayUnit;
+  QString mXUnit;
+  QString mXDisplayUnit;
+  QString mYUnit;
+  QString mYDisplayUnit;
   qreal mWidth;
   int mStyle;
+  bool mToggleSign;
+  QString mCustomTitle;
 
   Plot *mpParentPlot;
   QwtPlotDirectPainter *mpPlotDirectPainter;
   QwtPlotMarker *mpPointMarker;
 public:
-  PlotCurve(const QString &fileName, const QString &absoluteFilePath, const QString &name, const QString &xVariableName, const QString &yVariableName,
-            const QString &unit, const QString &displayUnit, Plot *pParent);
+  PlotCurve(const QString &fileName, const QString &absoluteFilePath, const QString &xVariableName, const QString &xUnit, const QString &xDisplayUnit,
+            const QString &yVariableName, const QString &yUnit, const QString &yDisplayUnit, Plot *pParent);
 
   QwtArray<double> mXAxisVector;
   QwtArray<double> mYAxisVector;
@@ -67,14 +68,22 @@ public:
   void setTitleLocal();
   Qt::PenStyle getPenStyle(int style);
   QwtPlotCurve::CurveStyle getCurveStyle(int style);
-  void setUnit(QString unit) {mUnit = unit;}
-  QString getUnit() {return mUnit;}
-  void setDisplayUnit(QString displayUnit) {mDisplayUnit = displayUnit;}
-  QString getDisplayUnit() {return mDisplayUnit;}
+  void setXUnit(QString xUnit) {mXUnit = xUnit;}
+  QString getXUnit() {return mXUnit;}
+  void setXDisplayUnit(QString xDisplayUnit) {mXDisplayUnit = xDisplayUnit;}
+  QString getXDisplayUnit() {return mXDisplayUnit;}
+  void setYUnit(QString yUnit) {mYUnit = yUnit;}
+  QString getYUnit() {return mYUnit;}
+  void setYDisplayUnit(QString yDisplayUnit) {mYDisplayUnit = yDisplayUnit;}
+  QString getYDisplayUnit() {return mYDisplayUnit;}
   void setCurveWidth(qreal width);
   qreal getCurveWidth() {return mWidth;}
   void setCurveStyle(int style);
   int getCurveStyle() {return mStyle;}
+  bool getToggleSign() const {return mToggleSign;}
+  void setToggleSign(bool toggleSign) {mToggleSign = toggleSign;}
+  QString getCustomTitle() const {return mCustomTitle;}
+  void setCustomTitle(const QString &customTitle) {mCustomTitle = customTitle;}
   void setXAxisVector(QVector<double> vector);
   void addXAxisValue(double value);
   void updateXAxisValue(int index, double value);
@@ -87,7 +96,6 @@ public:
   const double* getYAxisVector() const;
   void clearYAxisVector() {mYAxisVector.clear();}
   int getSize();
-  QString getName() {return mName;}
   void setFileName(QString fileName);
   QString getFileName() const;
   QString getAbsoluteFilePath() const;
@@ -99,7 +107,7 @@ public:
   QString getYVariable();
   void setCustomColor(bool value);
   bool hasCustomColor();
-  void toggleVisibility();
+  void toggleVisibility(bool visibility);
   void setData(const double* xData, const double* yData, int size);
   QwtPlotDirectPainter* getPlotDirectPainter() {return mpPlotDirectPainter;}
   QwtPlotMarker* getPointMarker() const {return mpPointMarker;}
