@@ -54,9 +54,6 @@
 #include "omcinteractiveenvironment.h"
 #include "otherdlg.h"
 
-
-using namespace std;
-
 static QString omc_version_;
 static QString omhome;
 static IAEX::OmcInteractiveEnvironment* delegate_;
@@ -155,9 +152,9 @@ bool MyTextEdit::insideCommandSign()
     int cursorPos = textCursor().position();
     if( blockStartPos <= cursorPos && cursorPos < (blockStartPos+3) && signPos == 0)
     {
-      cerr << "Inside Command Sign" << endl;
-      cerr << "BlockStart: " << blockStartPos <<
-        ", Cursor: " << cursorPos << endl << endl;
+      std::cerr << "Inside Command Sign" << std::endl;
+      std::cerr << "BlockStart: " << blockStartPos <<
+        ", Cursor: " << cursorPos << std::endl << std::endl;
 
       return true;
     }
@@ -165,7 +162,7 @@ bool MyTextEdit::insideCommandSign()
       return false;
   }
   else
-    cerr << "Not a valid QTextBlock (insideCommandSign)" << endl;
+    std::cerr << "Not a valid QTextBlock (insideCommandSign)" << std::endl;
 
   return true;
 }
@@ -184,7 +181,7 @@ bool MyTextEdit::startOfCommandSign()
       return false;
   }
   else
-    cerr << "Not a valid QTextBlock (startOfCommandSign)" << endl;
+    std::cerr << "Not a valid QTextBlock (startOfCommandSign)" << std::endl;
 
   return true;
 }
@@ -275,7 +272,7 @@ OMS::OMS( QWidget* parent )
 
     commandcompletion_ = IAEX::CommandCompletion::instance( commandfile );
   }
-  catch( exception &e )
+  catch( std::exception &e )
   {
     QString msg = e.what();
     msg += "\nCould not create command completion class!";
@@ -480,7 +477,7 @@ void OMS::returnPressed()
     }
     else
     {
-      cerr << "Not a valid QTextBlock (returnPressed)" << endl;
+      std::cerr << "Not a valid QTextBlock (returnPressed)" << std::endl;
       break;
     }
   }
@@ -493,7 +490,7 @@ void OMS::returnPressed()
   currentCommand_ = -1;
 
   // remove any newline
-  commandText.simplified();
+  commandText = commandText.simplified();
 
   // if 'quit()' exit OMShell
   if( commandText == "quit()" )
@@ -510,7 +507,7 @@ void OMS::returnPressed()
     {
       delegate_->evalExpression( commandText );
     }
-    catch( exception &e )
+    catch( std::exception &e )
     {
       exceptionInEval(e);
       return;
@@ -525,32 +522,22 @@ void OMS::returnPressed()
       cursor_.insertText( "\n" + res + "\n", textFormat_ );
 
     // get Error text
-    try
+    QString error = delegate_->getError();
+    if(error.size() > 2)
     {
-      QString getErrorString = "getErrorString()";
-      delegate_->evalExpression(getErrorString);
-    }
-    catch( exception &e )
-    {
-      exceptionInEval(e);
-      return;
-    }
-    QString error = delegate_->getResult();
-    if( error.size() > 2 )
-    {
-      cursor_.insertText( error.mid( 1, error.size() - 2 ) );
+      cursor_.insertText(error);
     }
   }
   else
   {
-    cursor_.insertText("[ERROR] No OMC serer started - unable to restart OMC\n" );
+    cursor_.insertText("[ERROR] No OMC server started - unable to restart OMC\n" );
   }
 
   // add new command line
   addCommandLine();
 }
 
-void OMS::exceptionInEval(exception &e)
+void OMS::exceptionInEval(std::exception &e)
 {
   // 2006-0-09 AF, try to reconnect to OMC first.
   returnPressed();
@@ -640,7 +627,7 @@ void OMS::goHome( bool shift )
     moshEdit_->setTextCursor( cursor_ );
   }
   else
-    cout << "Not a valid QTextBlock (selectCommandLine)" << endl;
+    std::cout << "Not a valid QTextBlock (selectCommandLine)" << std::endl;
 }
 
 void OMS::codeCompletion( bool same )
@@ -699,7 +686,7 @@ void OMS::selectCommandLine()
     }
     else
     {
-      cout << "Not a valid QTextBlock (selectCommandLine)" << endl;
+      std::cout << "Not a valid QTextBlock (selectCommandLine)" << std::endl;
       break;
     }
   }
@@ -715,7 +702,7 @@ void OMS::loadModel()
   QString filename = QFileDialog::getOpenFileName(
     this,
     "OMShell - Load Model",
-    QString::null,
+    QString(),
     "Modelica files (*.mo)" );
 
   if( !filename.isNull() )
