@@ -41,9 +41,6 @@
 
 #include <exception>
 
-using namespace std;
-
-
 // QT Headers
 #include <QtGlobal>
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
@@ -72,7 +69,6 @@ using namespace std;
 #endif
 
 //IAEX Headers
-#include "inputcelldelegate.h"
 #include "commandcompletion.h"
 
 //Forward Declaration
@@ -112,8 +108,6 @@ public slots:
   void aboutOMS();
   void aboutQT();          // Added 2006-02-21 AF
   void print();
-  static bool startServer();
-  static void stopServer();
   void clear();
 
 private slots:
@@ -125,7 +119,7 @@ private:
   void createAction();
   void createMenu();
   void createToolbar();
-  void exceptionInEval(exception &e);
+  void exceptionInEval(std::exception &e);
   void addCommandLine();
   void selectCommandLine();
   QStringList getFunctionNames(QString);
