@@ -3,7 +3,7 @@
 #include <lualib.h>
 #include <stdlib.h>
 
-#include <OMSimulator.h>
+#include "OMSimulator/OMSimulator.h"
 
 #define REGISTER_LUA_CALL(name) lua_register(L, #name, OMSimulatorLua_##name)
 #define REGISTER_LUA_ENUM(name) lua_pushnumber(L, name); lua_setglobal(L, #name)
@@ -206,6 +206,20 @@ static int OMSimulatorLua_oms_delete(lua_State *L)
   return 1;
 }
 
+//oms_status_enu_t oms_deleteResources(const char* cref);
+static int OMSimulatorLua_oms_deleteResources(lua_State *L)
+{
+  if (lua_gettop(L) != 1)
+    return luaL_error(L, "expecting exactly 1 argument");
+  luaL_checktype(L, 1, LUA_TSTRING);
+
+  const char* cref = lua_tostring(L, 1);
+  oms_status_enu_t status = oms_deleteResources(cref);
+
+  lua_pushinteger(L, status);
+  return 1;
+}
+
 //oms_status_enu_t oms_export(const char* cref, const char* filename);
 static int OMSimulatorLua_oms_export(lua_State *L)
 {
@@ -258,6 +272,26 @@ static int OMSimulatorLua_oms_list(lua_State *L)
   return 2;
 }
 
+//oms_status_enu_t oms_list(const char* cref, char** contents);
+static int OMSimulatorLua_oms_listVariants(lua_State *L)
+{
+  if (lua_gettop(L) != 1)
+    return luaL_error(L, "expecting exactly 1 argument");
+  luaL_checktype(L, 1, LUA_TSTRING);
+
+  const char* cref = lua_tostring(L, 1);
+  char* contents = NULL;
+  oms_status_enu_t status = oms_listVariants(cref, &contents);
+
+  lua_pushstring(L, contents ? contents : "");
+  lua_pushinteger(L, status);
+
+  if (contents)
+    oms_freeMemory(contents);
+
+  return 2;
+}
+
 //oms_status_enu_t oms_exportSnapshot(const char* cref, char** contents);
 static int OMSimulatorLua_oms_exportSnapshot(lua_State *L)
 {
@@ -294,6 +328,33 @@ static int OMSimulatorLua_oms_exportSSVTemplate(lua_State *L)
   return 1;
 }
 
+//oms_status_enu_t oms_reduceSSV(const char* ssvfile, const char* ssmfile, const char* filepath);
+static int OMSimulatorLua_oms_reduceSSV(lua_State *L)
+{
+  if (lua_gettop(L) != 3 && lua_gettop(L) != 4)
+    return luaL_error(L, "expecting exactly 3 or 4 arguments");
+
+  luaL_checktype(L, 1, LUA_TSTRING);
+  luaL_checktype(L, 2, LUA_TSTRING);
+  luaL_checktype(L, 3, LUA_TSTRING);
+
+  const char* cref = lua_tostring(L, 1);
+  const char* ssvfile = lua_tostring(L, 2);
+  const char* ssmfile = lua_tostring(L, 3);
+
+  const char* filepath = "";
+  if (lua_gettop(L) == 4)
+  {
+    luaL_checktype(L, 4, LUA_TSTRING);
+    filepath = lua_tostring(L, 4);
+  }
+
+  oms_status_enu_t status = oms_reduceSSV(cref, ssvfile, ssmfile, filepath);
+
+  lua_pushinteger(L, status);
+  return 1;
+}
+
 //oms_status_enu_t oms_exportSSMTemplate(const char* cref, const char* filename);
 static int OMSimulatorLua_oms_exportSSMTemplate(lua_State *L)
 {
@@ -412,15 +473,53 @@ static int OMSimulatorLua_oms_compareSimulationResults(lua_State *L)
   return 1;
 }
 
-//oms_status_enu_t oms_addResources(const char* cref);
-static int OMSimulatorLua_oms_addResources(lua_State *L)
+//oms_status_enu_t oms_newResources(const char* cref);
+static int OMSimulatorLua_oms_newResources(lua_State *L)
 {
   if (lua_gettop(L) != 1)
     return luaL_error(L, "expecting exactly 1 argument");
   luaL_checktype(L, 1, LUA_TSTRING);
 
   const char* cref = lua_tostring(L, 1);
-  oms_status_enu_t status = oms_addResources(cref);
+  oms_status_enu_t status = oms_newResources(cref);
+
+  lua_pushinteger(L, status);
+  return 1;
+}
+
+//oms_status_enu_t oms_referenceResources(const char* cref, const char* ssmFile);
+static int OMSimulatorLua_oms_referenceResources(lua_State *L)
+{
+  if (lua_gettop(L) != 1 && lua_gettop(L) != 2)
+    return luaL_error(L, "expecting exactly 1 or 2 argument");
+  luaL_checktype(L, 1, LUA_TSTRING);
+
+  const char* cref = lua_tostring(L, 1);
+
+  const char* ssmFile = "";
+  if (lua_gettop(L) == 2)
+  {
+    luaL_checktype(L, 2, LUA_TSTRING);
+    ssmFile = lua_tostring(L, 2);
+  }
+
+  oms_status_enu_t status = oms_referenceResources(cref, ssmFile);
+
+  lua_pushinteger(L, status);
+  return 1;
+}
+
+//oms_status_enu_t oms_addResources(const char* cref, const char* path);
+static int OMSimulatorLua_oms_addResources(lua_State *L)
+{
+  if (lua_gettop(L) != 2)
+    return luaL_error(L, "expecting exactly 2 argument");
+  luaL_checktype(L, 1, LUA_TSTRING);
+  luaL_checktype(L, 2, LUA_TSTRING);
+
+  const char* cref = lua_tostring(L, 1);
+  const char* path = lua_tostring(L, 2);
+  oms_status_enu_t status = oms_addResources(cref, path);
 
   lua_pushinteger(L, status);
   return 1;
@@ -595,6 +694,93 @@ static int OMSimulatorLua_oms_getReal(lua_State *L)
   return 2;
 }
 
+//oms_status_enu_t oms_getString(const char* cref, char** value);
+static int OMSimulatorLua_oms_getString(lua_State *L)
+{
+  if (lua_gettop(L) != 1)
+    return luaL_error(L, "expecting exactly 1 argument");
+  luaL_checktype(L, 1, LUA_TSTRING);
+
+  const char* cref = lua_tostring(L, 1);
+  char* value = NULL;
+  oms_status_enu_t status = oms_getString(cref, &value);
+
+  lua_pushstring(L, value ? value : "");
+  lua_pushinteger(L, status);
+
+  if (value)
+    oms_freeMemory(value);
+  return 2;
+}
+
+
+//oms_status_enu_t oms_getDirectionalDerivative(const ComRef& unknownCref, const ComRef& knownCref, double* value);
+static int OMSimulatorLua_oms_getDirectionalDerivative(lua_State *L)
+{
+  if (lua_gettop(L) != 1 && lua_gettop(L) != 2)
+    return luaL_error(L, "expecting exactly 1 or 2 argument");
+  luaL_checktype(L, 1, LUA_TSTRING);
+
+  const char* unknownCref = lua_tostring(L, 1);
+  const char* knownCref = "";
+  if (lua_gettop(L) == 2)
+  {
+    luaL_checktype(L, 2, LUA_TSTRING);
+    knownCref = lua_tostring(L, 2);
+  }
+  double value = 0.0;
+
+  oms_status_enu_t status = oms_getDirectionalDerivative(unknownCref, knownCref, &value);
+  lua_pushnumber(L, value);
+  lua_pushinteger(L, status);
+  return 2;
+}
+
+//oms_status_enu_t oms_getState(const char* cref);
+static int OMSimulatorLua_oms_getState(lua_State *L)
+{
+  if (lua_gettop(L) != 1)
+    return luaL_error(L, "expecting exactly 1 argument");
+  luaL_checktype(L, 1, LUA_TSTRING);
+
+  const char* cref = lua_tostring(L, 1);
+  oms_status_enu_t status = oms_getState(cref);
+
+  lua_pushinteger(L, status);
+
+  return 1;
+}
+
+//oms_status_enu_t oms_setState(const char* cref);
+static int OMSimulatorLua_oms_setState(lua_State *L)
+{
+  if (lua_gettop(L) != 1)
+    return luaL_error(L, "expecting exactly 1 argument");
+  luaL_checktype(L, 1, LUA_TSTRING);
+
+  const char* cref = lua_tostring(L, 1);
+  oms_status_enu_t status = oms_setState(cref);
+
+  lua_pushinteger(L, status);
+
+  return 1;
+}
+
+//oms_status_enu_t oms_freeState(const char* cref);
+static int OMSimulatorLua_oms_freeState(lua_State *L)
+{
+  if (lua_gettop(L) != 1)
+    return luaL_error(L, "expecting exactly 1 argument");
+  luaL_checktype(L, 1, LUA_TSTRING);
+
+  const char* cref = lua_tostring(L, 1);
+  oms_status_enu_t status = oms_freeState(cref);
+
+  lua_pushinteger(L, status);
+
+  return 1;
+}
+
 //OMSAPI oms_status_enu_t OMSCALL oms_getSolver(const char* cref, oms_solver_enu_t* solver);
 static int OMSimulatorLua_oms_getSolver(lua_State *L)
 {
@@ -659,6 +845,38 @@ static int OMSimulatorLua_oms_setReal(lua_State *L)
   return 1;
 }
 
+// oms_status_enu_t oms_setString(const char* cref, const char* value);
+static int OMSimulatorLua_oms_setString(lua_State *L)
+{
+  if (lua_gettop(L) != 2)
+    return luaL_error(L, "expecting exactly 2 arguments");
+  luaL_checktype(L, 1, LUA_TSTRING);
+  luaL_checktype(L, 2, LUA_TSTRING);
+
+  const char* cref = lua_tostring(L, 1);
+  const char* value = lua_tostring(L, 2);
+
+  oms_status_enu_t status = oms_setString(cref, value);
+  lua_pushinteger(L, status);
+  return 1;
+}
+
+// oms_status_enu_t oms_setUnit(const char* cref, const char* value);
+static int OMSimulatorLua_oms_setUnit(lua_State *L)
+{
+  if (lua_gettop(L) != 2)
+    return luaL_error(L, "expecting exactly 2 arguments");
+  luaL_checktype(L, 1, LUA_TSTRING);
+  luaL_checktype(L, 2, LUA_TSTRING);
+
+  const char* cref = lua_tostring(L, 1);
+  const char* value = lua_tostring(L, 2);
+
+  oms_status_enu_t status = oms_setUnit(cref, value);
+  lua_pushinteger(L, status);
+  return 1;
+}
+
 // OMSAPI oms_status_enu_t OMSCALL oms_setRealInputDerivative(const char* cref, double value);
 static int OMSimulatorLua_oms_setRealInputDerivative(lua_State *L)
 {
@@ -694,17 +912,25 @@ static int OMSimulatorLua_oms_addConnector(lua_State *L)
   return 1;
 }
 
-//oms_status_enu_t oms_addConnection(const char *crefA, const char *crefB);
+//oms_status_enu_t oms_addConnection(const char *crefA, const char *crefB, bool suppressUnitConversion);
 static int OMSimulatorLua_oms_addConnection(lua_State *L)
 {
-  if (lua_gettop(L) != 2)
-    return luaL_error(L, "expecting exactly 2 arguments");
+  if (lua_gettop(L) != 2 && lua_gettop(L) != 3)
+    return luaL_error(L, "expecting exactly 2 or 3 arguments");
   luaL_checktype(L, 1, LUA_TSTRING);
   luaL_checktype(L, 2, LUA_TSTRING);
 
   const char* crefA = lua_tostring(L, 1);
   const char* crefB = lua_tostring(L, 2);
-  oms_status_enu_t status = oms_addConnection(crefA, crefB);
+
+  bool suppressUnitConversion = false;
+  if (lua_gettop(L) == 3)
+  {
+    luaL_checktype(L, 3, LUA_TBOOLEAN);
+    suppressUnitConversion = lua_toboolean(L, 3);
+  }
+
+  oms_status_enu_t status = oms_addConnection(crefA, crefB, suppressUnitConversion);
 
   lua_pushinteger(L, status);
 
@@ -972,6 +1198,81 @@ static int OMSimulatorLua_oms_addSubModel(lua_State *L)
   return 1;
 }
 
+//oms_status_enu_t oms_activateVariant(const char* crefA, const char* crefB)
+static int OMSimulatorLua_oms_activateVariant(lua_State *L)
+{
+  if (lua_gettop(L) != 2)
+    return luaL_error(L, "expecting exactly 2 arguments");
+  luaL_checktype(L, 1, LUA_TSTRING);
+  luaL_checktype(L, 2, LUA_TSTRING);
+
+  const char* crefA = lua_tostring(L, 1);
+  const char* crefB = lua_tostring(L, 2);
+
+
+  oms_status_enu_t status = oms_activateVariant(crefA, crefB);
+
+  if (status!=oms_status_ok)
+  {
+    return luaL_error(L, "oms_activateVariant(%s,%s) failed", crefA, crefB);
+  }
+
+  lua_pushinteger(L, status);
+
+  return 1;
+}
+
+//oms_status_enu_t oms_duplicateVariant(const char* crefA, const char* crefB)
+static int OMSimulatorLua_oms_duplicateVariant(lua_State *L)
+{
+  if (lua_gettop(L) != 2)
+    return luaL_error(L, "expecting exactly 2 arguments");
+  luaL_checktype(L, 1, LUA_TSTRING);
+  luaL_checktype(L, 2, LUA_TSTRING);
+
+  const char* crefA = lua_tostring(L, 1);
+  const char* crefB = lua_tostring(L, 2);
+
+
+  oms_status_enu_t status = oms_duplicateVariant(crefA, crefB);
+
+  if (status!=oms_status_ok)
+  {
+    return luaL_error(L, "oms_duplicateVariant(%s,%s) failed", crefA, crefB);
+  }
+
+  lua_pushinteger(L, status);
+
+  return 1;
+}
+
+//oms_status_enu_t oms_replaceSubModel(const char* cref, const char* fmuPath, bool dryRun);
+static int OMSimulatorLua_oms_replaceSubModel(lua_State *L)
+{
+  if (lua_gettop(L) != 3)
+    return luaL_error(L, "expecting exactly 3 arguments");
+  luaL_checktype(L, 1, LUA_TSTRING);
+  luaL_checktype(L, 2, LUA_TSTRING);
+  luaL_checktype(L, 3, LUA_TBOOLEAN);
+
+  const char* cref = lua_tostring(L, 1);
+  const char* fmuPath = lua_tostring(L, 2);
+  bool dryRun = lua_toboolean(L, 3);
+  int warningCount = 0;
+
+  oms_status_enu_t status = oms_replaceSubModel(cref, fmuPath, dryRun, &warningCount);
+
+  if (status!=oms_status_ok)
+  {
+    return luaL_error(L, "oms_replaceSubModel(%s,%s,%s) failed", cref, fmuPath, dryRun);
+  }
+
+  lua_pushinteger(L, warningCount);
+  lua_pushinteger(L, status);
+
+  return 2;
+}
+
 //oms_status_enu_t oms_instantiate(const char* ident);
 static int OMSimulatorLua_oms_instantiate(lua_State *L)
 {
@@ -1264,6 +1565,7 @@ static int OMSimulatorLua_oms_setFixedStepSize(lua_State *L)
 
 DLLEXPORT int luaopen_OMSimulatorLua(lua_State *L)
 {
+  REGISTER_LUA_CALL(oms_activateVariant);
   REGISTER_LUA_CALL(oms_addBus);
   REGISTER_LUA_CALL(oms_addConnection);
   REGISTER_LUA_CALL(oms_addConnector);
@@ -1286,6 +1588,8 @@ DLLEXPORT int luaopen_OMSimulatorLua(lua_State *L)
   REGISTER_LUA_CALL(oms_deleteConnection);
   REGISTER_LUA_CALL(oms_deleteConnectorFromBus);
   REGISTER_LUA_CALL(oms_deleteConnectorFromTLMBus);
+  REGISTER_LUA_CALL(oms_deleteResources);
+  REGISTER_LUA_CALL(oms_duplicateVariant);
   REGISTER_LUA_CALL(oms_export);
   REGISTER_LUA_CALL(oms_exportDependencyGraphs);
   REGISTER_LUA_CALL(oms_exportSnapshot);
@@ -1293,14 +1597,19 @@ DLLEXPORT int luaopen_OMSimulatorLua(lua_State *L)
   REGISTER_LUA_CALL(oms_exportSSMTemplate);
   REGISTER_LUA_CALL(oms_faultInjection);
   REGISTER_LUA_CALL(oms_getBoolean);
+  REGISTER_LUA_CALL(oms_getDirectionalDerivative);
   REGISTER_LUA_CALL(oms_getFixedStepSize);
   REGISTER_LUA_CALL(oms_getInteger);
   REGISTER_LUA_CALL(oms_getModelState);
   REGISTER_LUA_CALL(oms_getReal);
+  REGISTER_LUA_CALL(oms_getString);
   REGISTER_LUA_CALL(oms_getSolver);
   REGISTER_LUA_CALL(oms_getStartTime);
   REGISTER_LUA_CALL(oms_getStopTime);
   REGISTER_LUA_CALL(oms_getSystemType);
+  REGISTER_LUA_CALL(oms_getState);
+  REGISTER_LUA_CALL(oms_setState);
+  REGISTER_LUA_CALL(oms_freeState);
   REGISTER_LUA_CALL(oms_getVariableStepSize);
   REGISTER_LUA_CALL(oms_getVersion);
   REGISTER_LUA_CALL(oms_importFile);
@@ -1308,12 +1617,17 @@ DLLEXPORT int luaopen_OMSimulatorLua(lua_State *L)
   REGISTER_LUA_CALL(oms_initialize);
   REGISTER_LUA_CALL(oms_instantiate);
   REGISTER_LUA_CALL(oms_list);
+  REGISTER_LUA_CALL(oms_listVariants);
   REGISTER_LUA_CALL(oms_listUnconnectedConnectors);
   REGISTER_LUA_CALL(oms_loadSnapshot);
   REGISTER_LUA_CALL(oms_newModel);
+  REGISTER_LUA_CALL(oms_newResources);
   REGISTER_LUA_CALL(oms_removeSignalsFromResults);
   REGISTER_LUA_CALL(oms_rename);
+  REGISTER_LUA_CALL(oms_replaceSubModel);
   REGISTER_LUA_CALL(oms_reset);
+  REGISTER_LUA_CALL(oms_referenceResources);
+  REGISTER_LUA_CALL(oms_reduceSSV);
   REGISTER_LUA_CALL(oms_setBoolean);
   REGISTER_LUA_CALL(oms_setCommandLineOption);
   REGISTER_LUA_CALL(oms_setFixedStepSize);
@@ -1326,6 +1640,7 @@ DLLEXPORT int luaopen_OMSimulatorLua(lua_State *L)
   REGISTER_LUA_CALL(oms_setRealInputDerivative);
   REGISTER_LUA_CALL(oms_setResultFile);
   REGISTER_LUA_CALL(oms_setSolver);
+  REGISTER_LUA_CALL(oms_setString);
   REGISTER_LUA_CALL(oms_setStartTime);
   REGISTER_LUA_CALL(oms_setStopTime);
   REGISTER_LUA_CALL(oms_setTempDirectory);
@@ -1335,6 +1650,7 @@ DLLEXPORT int luaopen_OMSimulatorLua(lua_State *L)
   REGISTER_LUA_CALL(oms_setVariableStepSize);
   REGISTER_LUA_CALL(oms_setWorkingDirectory);
   REGISTER_LUA_CALL(oms_simulate);
+  REGISTER_LUA_CALL(oms_setUnit);
   REGISTER_LUA_CALL(oms_stepUntil);
   REGISTER_LUA_CALL(oms_terminate);
 
